# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protobufs/main.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='protobufs/main.proto',
  package='zaber.motion.protobufs',
  syntax='proto3',
  serialized_options=b'Z protobufs;zaber_motion_protobufs',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x14protobufs/main.proto\x12\x16zaber.motion.protobufs\"\x1a\n\x07Request\x12\x0f\n\x07request\x18\x01 \x01(\t\"\xb9\x01\n\x08Response\x12?\n\x08response\x18\x01 \x01(\x0e\x32-.zaber.motion.protobufs.Response.ResponseType\x12\x32\n\nerror_type\x18\x02 \x01(\x0e\x32\x1e.zaber.motion.protobufs.Errors\x12\x15\n\rerror_message\x18\x03 \x01(\t\"!\n\x0cResponseType\x12\x06\n\x02OK\x10\x00\x12\t\n\x05\x45RROR\x10\x01\"\x16\n\x05\x45vent\x12\r\n\x05\x65vent\x18\x01 \x01(\t\"\x0e\n\x0c\x45mptyRequest\"\xc8\x01\n\x0c\x41xisIdentity\x12\x15\n\ris_peripheral\x18\x01 \x01(\x08\x12\x15\n\rperipheral_id\x18\x02 \x01(\x05\x12\x17\n\x0fperipheral_name\x18\x03 \x01(\t\x12@\n\taxis_type\x18\x04 \x01(\x0e\x32-.zaber.motion.protobufs.AxisIdentity.AxisType\"/\n\x08\x41xisType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06LINEAR\x10\x01\x12\n\n\x06ROTARY\x10\x02\"\x9f\x01\n\x0e\x44\x65viceIdentity\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x15\n\rserial_number\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\naxis_count\x18\x04 \x01(\x05\x12\x41\n\x10\x66irmware_version\x18\x05 \x01(\x0b\x32\'.zaber.motion.protobufs.FirmwareVersion\">\n\x0f\x46irmwareVersion\x12\r\n\x05major\x18\x01 \x01(\x05\x12\r\n\x05minor\x18\x02 \x01(\x05\x12\r\n\x05\x62uild\x18\x03 \x01(\x05\"\x9d\x01\n\x0c\x44\x65viceIOInfo\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x1d\n\x15number_analog_outputs\x18\x02 \x01(\x05\x12\x1c\n\x14number_analog_inputs\x18\x03 \x01(\x05\x12\x1e\n\x16number_digital_outputs\x18\x04 \x01(\x05\x12\x1d\n\x15number_digital_inputs\x18\x05 \x01(\x05\"*\n\x0bMeasurement\x12\r\n\x05value\x18\x01 \x01(\x01\x12\x0c\n\x04unit\x18\x07 \x01(\t\">\n\x14StreamAxisDefinition\x12\x13\n\x0b\x61xis_number\x18\x01 \x01(\x05\x12\x11\n\taxis_type\x18\x02 \x01(\x05\"6\n\x0bTestRequest\x12\x14\n\x0creturn_error\x18\x01 \x01(\x08\x12\x11\n\tdata_ping\x18\x02 \x01(\t\"!\n\x0cTestResponse\x12\x11\n\tdata_pong\x18\x01 \x01(\t\"%\n\x10TestResponseLong\x12\x11\n\tdata_pong\x18\x01 \x03(\t\"\x19\n\tTestEvent\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\t\"-\n\x1cToolsListSerialPortsResponse\x12\r\n\x05ports\x18\x01 \x03(\t\"I\n\x18SetDeviceDbSourceRequest\x12\x13\n\x0bsource_type\x18\x01 \x01(\x05\x12\x18\n\x10url_or_file_path\x18\x02 \x01(\t\"G\n\x1aToggleDeviceDbStoreRequest\x12\x11\n\ttoggle_on\x18\x01 \x01(\x08\x12\x16\n\x0estore_location\x18\x02 \x01(\t\"\x9c\x01\n\x14OpenInterfaceRequest\x12=\n\x0einterface_type\x18\x01 \x01(\x0e\x32%.zaber.motion.protobufs.InterfaceType\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x11\n\tbaud_rate\x18\x03 \x01(\x05\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x05\"-\n\x15OpenInterfaceResponse\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"-\n\x15\x43loseInterfaceRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"-\n\x15\x45mptyInterfaceRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\",\n\x1bGetInterfaceTimeoutResponse\x12\r\n\x05value\x18\x01 \x01(\x05\"C\n\x1aSetInterfaceTimeoutRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0f\n\x07timeout\x18\x02 \x01(\x05\"4\n#GetInterfaceChecksumEnabledResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"N\n\"SetInterfaceChecksumEnabledRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x12\n\nis_enabled\x18\x02 \x01(\x08\"E\n\x0fToStringRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"\"\n\x10ToStringResponse\x12\x0e\n\x06to_str\x18\x01 \x01(\t\"\x83\x01\n\x15GenericCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x04 \x01(\t\x12\x14\n\x0c\x63heck_errors\x18\x05 \x01(\x08\x12\x0f\n\x07timeout\x18\x06 \x01(\x05\"\xc8\x01\n\x16GenericCommandResponse\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x12\n\nreply_flag\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\t\x12\x39\n\x0cmessage_type\x18\x08 \x01(\x0e\x32#.zaber.motion.protobufs.MessageType\"e\n GenericCommandResponseCollection\x12\x41\n\tresponses\x18\x02 \x03(\x0b\x32..zaber.motion.protobufs.GenericCommandResponse\"\xdc\x01\n\x14UnknownResponseEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x12\n\nreply_flag\x18\x04 \x01(\t\x12\x0e\n\x06status\x18\x05 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x06 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x07 \x01(\t\x12\x39\n\x0cmessage_type\x18\x08 \x01(\x0e\x32#.zaber.motion.protobufs.MessageType\"\x83\x01\n\nAlertEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x13\n\x0b\x61xis_number\x18\x03 \x01(\x05\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x14\n\x0cwarning_flag\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\"t\n\x11\x44isconnectedEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x32\n\nerror_type\x18\x02 \x01(\x0e\x32\x1e.zaber.motion.protobufs.Errors\x12\x15\n\rerror_message\x18\x03 \x01(\t\"D\n\x15\x44\x65viceRenumberRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x15\n\rfirst_address\x18\x02 \x01(\x05\"0\n\x16\x44\x65viceRenumberResponse\x12\x16\n\x0enumber_devices\x18\x01 \x01(\x05\"E\n\x13\x44\x65viceDetectRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x18\n\x10identify_devices\x18\x02 \x01(\x08\"\'\n\x14\x44\x65viceDetectResponse\x12\x0f\n\x07\x64\x65vices\x18\x01 \x03(\x05\"`\n\x11\x44\x65viceHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"n\n\x1a\x44\x65viceWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"\xf6\x01\n\x11\x44\x65viceMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\x12@\n\x04type\x18\x05 \x01(\x0e\x32\x32.zaber.motion.protobufs.DeviceMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x06 \x01(\x01\x12\x0c\n\x04unit\x18\x07 \x01(\t\"7\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\x12\x07\n\x03MAX\x10\x03\x12\x07\n\x03MIN\x10\x04\"`\n\x11\x44\x65viceStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"=\n\x15\x44\x65viceIdentifyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"@\n\x18\x44\x65viceGetIdentityRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"U\n\x19\x44\x65viceGetIdentityResponse\x12\x38\n\x08identity\x18\x01 \x01(\x0b\x32&.zaber.motion.protobufs.DeviceIdentity\"D\n\x1c\x44\x65viceGetIsIdentifiedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"6\n\x1d\x44\x65viceGetIsIdentifiedResponse\x12\x15\n\ris_identified\x18\x01 \x01(\x08\"R\n\x1c\x44\x65viceGetAxisIdentityRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"W\n\x1d\x44\x65viceGetAxisIdentityResponse\x12\x36\n\x08identity\x18\x01 \x01(\x0b\x32$.zaber.motion.protobufs.AxisIdentity\"I\n\x13\x44\x65viceIsBusyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"\'\n\x14\x44\x65viceIsBusyResponse\x12\x0f\n\x07is_busy\x18\x01 \x01(\x08\"]\n\x18\x44\x65viceGetWarningsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\r\n\x05\x63lear\x18\x04 \x01(\x08\"*\n\x19\x44\x65viceGetWarningsResponse\x12\r\n\x05\x66lags\x18\x01 \x03(\t\"Z\n\x1c\x44\x65viceGetAllDigitalIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\"/\n\x1d\x44\x65viceGetAllDigitalIOResponse\x12\x0e\n\x06values\x18\x01 \x03(\x08\"Y\n\x1b\x44\x65viceGetAllAnalogIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\".\n\x1c\x44\x65viceGetAllAnalogIOResponse\x12\x0e\n\x06values\x18\x01 \x03(\x01\"o\n\x19\x44\x65viceGetDigitalIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\"+\n\x1a\x44\x65viceGetDigitalIOResponse\x12\r\n\x05value\x18\x01 \x01(\x08\"n\n\x18\x44\x65viceGetAnalogIORequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x14\n\x0c\x63hannel_type\x18\x03 \x01(\t\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\"*\n\x19\x44\x65viceGetAnalogIOResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"Y\n!DeviceSetAllDigitalOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0e\n\x06values\x18\x03 \x03(\x08\"X\n DeviceSetAllAnalogOutputsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0e\n\x06values\x18\x03 \x03(\x01\"l\n\x1d\x44\x65viceSetDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x08\"k\n\x1c\x44\x65viceSetAnalogOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x01\"F\n\x1e\x44\x65viceGetIOChannelsInfoRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"6\n\x13SetLogOutputRequest\x12\x0c\n\x04mode\x18\x01 \x01(\x05\x12\x11\n\tfile_path\x18\x02 \x01(\t\"l\n\x17\x44\x65viceGetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\")\n\x18\x44\x65viceGetSettingResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"\x94\x01\n\x1b\x44\x65viceConvertSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\x0c\n\x04unit\x18\x05 \x01(\t\x12\r\n\x05value\x18\x06 \x01(\x01\x12\x13\n\x0b\x66rom_native\x18\x07 \x01(\x08\"-\n\x1c\x44\x65viceConvertSettingResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"{\n\x17\x44\x65viceSetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x0f\n\x07setting\x18\x04 \x01(\t\x12\r\n\x05value\x18\x05 \x01(\x01\x12\x0c\n\x04unit\x18\x06 \x01(\t\"\x9e\x01\n\x15PrepareCommandRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\x12\x18\n\x10\x63ommand_template\x18\x04 \x01(\t\x12\x37\n\nparameters\x18\x05 \x03(\x0b\x32#.zaber.motion.protobufs.Measurement\")\n\x16PrepareCommandResponse\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\"G\n\x11\x44\x65viceParkRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0c\n\x04\x61xis\x18\x03 \x01(\x05\"+\n\x16\x44\x65viceIsParkedResponse\x12\x11\n\tis_parked\x18\x01 \x01(\x08\"f\n\x15LockstepEnableRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x04 \x03(\x05\"r\n\x16LockstepDisableRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"o\n\x13LockstepStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"o\n\x13LockstepHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\"\x87\x02\n\x13LockstepMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x17\n\x0fwait_until_idle\x18\x04 \x01(\x08\x12\x42\n\x04type\x18\x05 \x01(\x0e\x32\x34.zaber.motion.protobufs.LockstepMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x06 \x01(\x01\x12\x0c\n\x04unit\x18\x08 \x01(\t\"7\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\x12\x07\n\x03MAX\x10\x03\x12\x07\n\x03MIN\x10\x04\"}\n\x1cLockstepWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"X\n\x15LockstepIsBusyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\")\n\x16LockstepIsBusyResponse\x12\x0f\n\x07is_busy\x18\x01 \x01(\x08\"Y\n\x16LockstepGetAxesRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\"N\n\x0cLockstepAxes\x12\x0e\n\x06\x61xis_1\x18\x01 \x01(\x05\x12\x0e\n\x06\x61xis_2\x18\x02 \x01(\x05\x12\x0e\n\x06\x61xis_3\x18\x03 \x01(\x05\x12\x0e\n\x06\x61xis_4\x18\x04 \x01(\x05\"M\n\x17LockstepGetAxesResponse\x12\x32\n\x04\x61xes\x18\x01 \x01(\x0b\x32$.zaber.motion.protobufs.LockstepAxes\"h\n\x17LockstepGetTwistRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\")\n\x18LockstepGetTwistResponse\x12\r\n\x05twist\x18\x01 \x01(\x01\"+\n\x19LockstepGetTwistsResponse\x12\x0e\n\x06twists\x18\x01 \x03(\x01\"i\n\x18LockstepGetOffsetRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"+\n\x19LockstepGetOffsetResponse\x12\x0e\n\x06offset\x18\x01 \x01(\x01\"-\n\x1aLockstepGetOffsetsResponse\x12\x0f\n\x07offsets\x18\x01 \x03(\x01\"[\n\x18LockstepIsEnabledRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\"/\n\x19LockstepIsEnabledResponse\x12\x12\n\nis_enabled\x18\x01 \x01(\x08\"Z\n\x17LockstepToStringRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x19\n\x11lockstep_group_id\x18\x03 \x01(\x05\"*\n\x18LockstepToStringResponse\x12\x0e\n\x06to_str\x18\x01 \x01(\t\"_\n\x16StreamSetupLiveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x04 \x03(\x05\"\x96\x01\n\x1fStreamSetupLiveCompositeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12:\n\x04\x61xes\x18\x04 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"w\n\x17StreamSetupStoreRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\x12\x0c\n\x04\x61xes\x18\x05 \x03(\x05\"\xae\x01\n StreamSetupStoreCompositeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\x12:\n\x04\x61xes\x18\x05 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"\x8a\x01\n$StreamSetupStoreArbitraryAxesRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\x12\x12\n\naxes_count\x18\x05 \x01(\x05\"c\n\x11StreamCallRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x15\n\rstream_buffer\x18\x04 \x01(\x05\"\xf8\x01\n\x11StreamLineRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12<\n\x04type\x18\x04 \x01(\x0e\x32..zaber.motion.protobufs.StreamLineRequest.Type\x12\x35\n\x08\x65ndpoint\x18\x05 \x03(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\x06 \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\xb1\x03\n\x10StreamArcRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12;\n\x04type\x18\x04 \x01(\x0e\x32-.zaber.motion.protobufs.StreamArcRequest.Type\x12\x1a\n\x12rotation_direction\x18\x05 \x01(\x05\x12\x35\n\x08\x63\x65nter_x\x18\x06 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x35\n\x08\x63\x65nter_y\x18\x07 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x32\n\x05\x65nd_x\x18\x08 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x32\n\x05\x65nd_y\x18\t \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\n \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\xcf\x02\n\x13StreamCircleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12>\n\x04type\x18\x04 \x01(\x0e\x32\x30.zaber.motion.protobufs.StreamCircleRequest.Type\x12\x1a\n\x12rotation_direction\x18\x05 \x01(\x05\x12\x35\n\x08\x63\x65nter_x\x18\x06 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x35\n\x08\x63\x65nter_y\x18\x07 \x01(\x0b\x32#.zaber.motion.protobufs.Measurement\x12\x1b\n\x13target_axes_indices\x18\x08 \x03(\x05\"\x18\n\x04Type\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\"\x7f\n\x1dStreamWaitDigitalInputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\r\n\x05value\x18\x05 \x01(\x08\"\x91\x01\n\x1cStreamWaitAnalogInputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\x11\n\tcondition\x18\x05 \x01(\t\x12\r\n\x05value\x18\x06 \x01(\x01\"\x7f\n\x1dStreamSetDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\r\n\x05value\x18\x05 \x01(\x08\"~\n\x1cStreamSetAnalogOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\x12\r\n\x05value\x18\x05 \x01(\x01\"s\n StreamToggleDigitalOutputRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x16\n\x0e\x63hannel_number\x18\x04 \x01(\x05\"h\n\x11StreamWaitRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04time\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"s\n\x1aStreamWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x1c\n\x14throw_error_on_fault\x18\x04 \x01(\x08\"L\n\x11StreamCorkRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"N\n\x13StreamUncorkRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"N\n\x13StreamIsBusyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"\'\n\x14StreamIsBusyResponse\x12\x0f\n\x07is_busy\x18\x01 \x01(\x08\"O\n\x14StreamGetAxesRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"S\n\x15StreamGetAxesResponse\x12:\n\x04\x61xes\x18\x01 \x03(\x0b\x32,.zaber.motion.protobufs.StreamAxisDefinition\"O\n\x14StreamGetModeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"%\n\x15StreamGetModeResponse\x12\x0c\n\x04mode\x18\x01 \x01(\x05\"a\n\x18StreamGetMaxSpeedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\".\n\x19StreamGetMaxSpeedResponse\x12\x11\n\tmax_speed\x18\x01 \x01(\x01\"t\n\x18StreamSetMaxSpeedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x11\n\tmax_speed\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"r\n)StreamGetMaxTangentialAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"Q\n*StreamGetMaxTangentialAccelerationResponse\x12#\n\x1bmax_tangential_acceleration\x18\x01 \x01(\x01\"\x97\x01\n)StreamSetMaxTangentialAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12#\n\x1bmax_tangential_acceleration\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"s\n*StreamGetMaxCentripetalAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"S\n+StreamGetMaxCentripetalAccelerationResponse\x12$\n\x1cmax_centripetal_acceleration\x18\x01 \x01(\x01\"\x99\x01\n*StreamSetMaxCentripetalAccelerationRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\x12$\n\x1cmax_centripetal_acceleration\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"P\n\x15StreamToStringRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"(\n\x16StreamToStringResponse\x12\x0e\n\x06to_str\x18\x01 \x01(\t\"O\n\x14StreamDisableRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tstream_id\x18\x03 \x01(\x05\"X\n\x1dStreamBufferGetContentRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tbuffer_id\x18\x03 \x01(\x05\"6\n\x1eStreamBufferGetContentResponse\x12\x14\n\x0c\x62uffer_lines\x18\x01 \x03(\t\"S\n\x18StreamBufferEraseRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x11\n\tbuffer_id\x18\x03 \x01(\x05\"c\n\x14\x42inaryReplyOnlyEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\"\xbb\x01\n\x1aOpenBinaryInterfaceRequest\x12=\n\x0einterface_type\x18\x01 \x01(\x0e\x32%.zaber.motion.protobufs.InterfaceType\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x11\n\tbaud_rate\x18\x03 \x01(\x05\x12\x11\n\thost_name\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x05\x12\x17\n\x0fuse_message_ids\x18\x06 \x01(\x08\"i\n\x1aUnknownBinaryResponseEvent\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x16\n\x0e\x64\x65vice_address\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\"\x82\x01\n\x14GenericBinaryRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x05\x12\x14\n\x0c\x63heck_errors\x18\x05 \x01(\x08\x12\x0f\n\x07timeout\x18\x06 \x01(\x01\"F\n\rBinaryMessage\x12\x16\n\x0e\x64\x65vice_address\x18\x01 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x02 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x05\"R\n\x17\x42inaryMessageCollection\x12\x37\n\x08messages\x18\x02 \x03(\x0b\x32%.zaber.motion.protobufs.BinaryMessage\"3\n\x1b\x42inaryDeviceRenumberRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\"6\n\x1c\x42inaryDeviceRenumberResponse\x12\x16\n\x0enumber_devices\x18\x01 \x01(\x05\"C\n\x1b\x42inaryDeviceIdentifyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"\xd9\x02\n\x14\x42inaryDeviceIdentity\x12\x11\n\tdevice_id\x18\x01 \x01(\x05\x12\x15\n\rserial_number\x18\x02 \x01(\r\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x41\n\x10\x66irmware_version\x18\x05 \x01(\x0b\x32\'.zaber.motion.protobufs.FirmwareVersion\x12\x15\n\ris_peripheral\x18\x06 \x01(\x08\x12\x15\n\rperipheral_id\x18\x07 \x01(\x05\x12\x17\n\x0fperipheral_name\x18\x08 \x01(\t\x12L\n\x0b\x64\x65vice_type\x18\t \x01(\x0e\x32\x37.zaber.motion.protobufs.BinaryDeviceIdentity.DeviceType\"1\n\nDeviceType\x12\x0b\n\x07UNKNOWN\x10\x00\x12\n\n\x06LINEAR\x10\x01\x12\n\n\x06ROTARY\x10\x02\"F\n\x1e\x42inaryDeviceGetIdentityRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"a\n\x1f\x42inaryDeviceGetIdentityResponse\x12>\n\x08identity\x18\x01 \x01(\x0b\x32,.zaber.motion.protobufs.BinaryDeviceIdentity\"J\n\"BinaryDeviceGetIsIdentifiedRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"<\n#BinaryDeviceGetIsIdentifiedResponse\x12\x15\n\ris_identified\x18\x01 \x01(\x08\"\x99\x01\n\x1d\x42inaryGenericWithUnitsRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07\x63ommand\x18\x03 \x01(\x05\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\x01\x12\x11\n\tfrom_unit\x18\x05 \x01(\t\x12\x0f\n\x07to_unit\x18\x06 \x01(\t\x12\x0f\n\x07timeout\x18\x07 \x01(\x01\".\n\x1e\x42inaryGenericWithUnitsResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x01\"^\n\x17\x42inaryDeviceHomeRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\",\n\x1c\x42inaryDeviceMovementResponse\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x01\"\xda\x01\n\x17\x42inaryDeviceMoveRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x46\n\x04type\x18\x04 \x01(\x0e\x32\x38.zaber.motion.protobufs.BinaryDeviceMoveRequest.MoveType\x12\x0b\n\x03\x61rg\x18\x05 \x01(\x01\x12\x0c\n\x04unit\x18\x06 \x01(\t\"%\n\x08MoveType\x12\x07\n\x03\x41\x42S\x10\x00\x12\x07\n\x03REL\x10\x01\x12\x07\n\x03VEL\x10\x02\"^\n\x17\x42inaryDeviceStopRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07timeout\x18\x03 \x01(\x01\x12\x0c\n\x04unit\x18\x04 \x01(\t\"H\n BinaryDeviceWaitUntilIdleRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"A\n\x19\x42inaryDeviceIsBusyRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"-\n\x1a\x42inaryDeviceIsBusyResponse\x12\x0f\n\x07is_busy\x18\x01 \x01(\x08\"K\n\x19\x42inaryDeviceDetectRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x18\n\x10identify_devices\x18\x02 \x01(\x08\"-\n\x1a\x42inaryDeviceDetectResponse\x12\x0f\n\x07\x64\x65vices\x18\x01 \x03(\x05\"d\n\x1d\x42inaryDeviceGetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07setting\x18\x03 \x01(\x05\x12\x0c\n\x04unit\x18\x04 \x01(\t\"/\n\x1e\x42inaryDeviceGetSettingResponse\x12\r\n\x05value\x18\x01 \x01(\x01\"s\n\x1d\x42inaryDeviceSetSettingRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\x12\x0f\n\x07setting\x18\x03 \x01(\x05\x12\r\n\x05value\x18\x04 \x01(\x01\x12\x0c\n\x04unit\x18\x05 \x01(\t\"?\n\x17\x42inaryDeviceParkRequest\x12\x14\n\x0cinterface_id\x18\x01 \x01(\x05\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\x05\"-\n\x18\x42inaryDeviceParkResponse\x12\x11\n\tis_parked\x18\x01 \x01(\x08*-\n\x0bMessageType\x12\t\n\x05REPLY\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\t\n\x05\x41LERT\x10\x02*\x9b\x06\n\x06\x45rrors\x12\x13\n\x0fREQUEST_TIMEOUT\x10\x00\x12\x15\n\x11\x43ONNECTION_CLOSED\x10\x01\x12\x14\n\x10INVALID_ARGUMENT\x10\x02\x12\x16\n\x12OUT_OF_REQUEST_IDS\x10\x03\x12\x12\n\x0eINVALID_PACKET\x10\x04\x12\x15\n\x11\x43ONNECTION_FAILED\x10\x05\x12\x13\n\x0fUNKNOWN_REQUEST\x10\x06\x12\x12\n\x0e\x43OMMAND_FAILED\x10\x07\x12\x14\n\x10\x44\x45VICE_DB_FAILED\x10\x08\x12\x10\n\x0cINVALID_DATA\x10\t\x12\x19\n\x15\x44\x45VICE_NOT_IDENTIFIED\x10\n\x12\x15\n\x11\x43ONVERSION_FAILED\x10\x0b\x12\x1b\n\x17\x44\x45VICE_ADDRESS_CONFLICT\x10\x0c\x12\x13\n\x0fNO_DEVICE_FOUND\x10\r\x12\x18\n\x14MOVEMENT_INTERRUPTED\x10\x0e\x12\x13\n\x0fMOVEMENT_FAILED\x10\x0f\x12\r\n\tIO_FAILED\x10\x10\x12\x14\n\x10INVALID_RESPONSE\x10\x11\x12\x11\n\rNOT_SUPPORTED\x10\x12\x12\x11\n\rDEVICE_FAILED\x10\x13\x12\r\n\tOS_FAILED\x10\x14\x12\x12\n\x0eINTERNAL_ERROR\x10\x16\x12\x19\n\x15\x42INARY_COMMAND_FAILED\x10\x18\x12\x15\n\x11\x43OMMAND_PREEMPTED\x10\x19\x12\x18\n\x14LOCKSTEP_NOT_ENABLED\x10\x1a\x12\x14\n\x10LOCKSTEP_ENABLED\x10\x1b\x12\x1b\n\x17IO_CHANNEL_OUT_OF_RANGE\x10\x1c\x12\x15\n\x11SETTING_NOT_FOUND\x10\x1d\x12\x0f\n\x0bSTREAM_MODE\x10\x1e\x12\x14\n\x10STREAM_EXECUTION\x10\x1f\x12\x1a\n\x16STREAM_MOVEMENT_FAILED\x10 \x12\x17\n\x13STREAM_SETUP_FAILED\x10!\x12\x0f\n\x0b\x44\x45VICE_BUSY\x10\"\x12\x1f\n\x1bSTREAM_MOVEMENT_INTERRUPTED\x10#\x12\x16\n\x12INVALID_PARK_STATE\x10$*)\n\rInterfaceType\x12\x0f\n\x0bSERIAL_PORT\x10\x00\x12\x07\n\x03TCP\x10\x01\x42\"Z protobufs;zaber_motion_protobufsb\x06proto3'
)

_MESSAGETYPE = _descriptor.EnumDescriptor(
  name='MessageType',
  full_name='zaber.motion.protobufs.MessageType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REPLY', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INFO', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ALERT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15839,
  serialized_end=15884,
)
_sym_db.RegisterEnumDescriptor(_MESSAGETYPE)

MessageType = enum_type_wrapper.EnumTypeWrapper(_MESSAGETYPE)
_ERRORS = _descriptor.EnumDescriptor(
  name='Errors',
  full_name='zaber.motion.protobufs.Errors',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='REQUEST_TIMEOUT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONNECTION_CLOSED', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_ARGUMENT', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OUT_OF_REQUEST_IDS', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PACKET', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONNECTION_FAILED', index=5, number=5,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN_REQUEST', index=6, number=6,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_FAILED', index=7, number=7,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_DB_FAILED', index=8, number=8,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_DATA', index=9, number=9,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_NOT_IDENTIFIED', index=10, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='CONVERSION_FAILED', index=11, number=11,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_ADDRESS_CONFLICT', index=12, number=12,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NO_DEVICE_FOUND', index=13, number=13,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOVEMENT_INTERRUPTED', index=14, number=14,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MOVEMENT_FAILED', index=15, number=15,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IO_FAILED', index=16, number=16,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_RESPONSE', index=17, number=17,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='NOT_SUPPORTED', index=18, number=18,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_FAILED', index=19, number=19,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='OS_FAILED', index=20, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INTERNAL_ERROR', index=21, number=22,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='BINARY_COMMAND_FAILED', index=22, number=24,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='COMMAND_PREEMPTED', index=23, number=25,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCKSTEP_NOT_ENABLED', index=24, number=26,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LOCKSTEP_ENABLED', index=25, number=27,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='IO_CHANNEL_OUT_OF_RANGE', index=26, number=28,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SETTING_NOT_FOUND', index=27, number=29,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STREAM_MODE', index=28, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STREAM_EXECUTION', index=29, number=31,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STREAM_MOVEMENT_FAILED', index=30, number=32,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STREAM_SETUP_FAILED', index=31, number=33,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='DEVICE_BUSY', index=32, number=34,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STREAM_MOVEMENT_INTERRUPTED', index=33, number=35,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PARK_STATE', index=34, number=36,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=15887,
  serialized_end=16682,
)
_sym_db.RegisterEnumDescriptor(_ERRORS)

Errors = enum_type_wrapper.EnumTypeWrapper(_ERRORS)
_INTERFACETYPE = _descriptor.EnumDescriptor(
  name='InterfaceType',
  full_name='zaber.motion.protobufs.InterfaceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SERIAL_PORT', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='TCP', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=16684,
  serialized_end=16725,
)
_sym_db.RegisterEnumDescriptor(_INTERFACETYPE)

InterfaceType = enum_type_wrapper.EnumTypeWrapper(_INTERFACETYPE)
REPLY = 0
INFO = 1
ALERT = 2
REQUEST_TIMEOUT = 0
CONNECTION_CLOSED = 1
INVALID_ARGUMENT = 2
OUT_OF_REQUEST_IDS = 3
INVALID_PACKET = 4
CONNECTION_FAILED = 5
UNKNOWN_REQUEST = 6
COMMAND_FAILED = 7
DEVICE_DB_FAILED = 8
INVALID_DATA = 9
DEVICE_NOT_IDENTIFIED = 10
CONVERSION_FAILED = 11
DEVICE_ADDRESS_CONFLICT = 12
NO_DEVICE_FOUND = 13
MOVEMENT_INTERRUPTED = 14
MOVEMENT_FAILED = 15
IO_FAILED = 16
INVALID_RESPONSE = 17
NOT_SUPPORTED = 18
DEVICE_FAILED = 19
OS_FAILED = 20
INTERNAL_ERROR = 22
BINARY_COMMAND_FAILED = 24
COMMAND_PREEMPTED = 25
LOCKSTEP_NOT_ENABLED = 26
LOCKSTEP_ENABLED = 27
IO_CHANNEL_OUT_OF_RANGE = 28
SETTING_NOT_FOUND = 29
STREAM_MODE = 30
STREAM_EXECUTION = 31
STREAM_MOVEMENT_FAILED = 32
STREAM_SETUP_FAILED = 33
DEVICE_BUSY = 34
STREAM_MOVEMENT_INTERRUPTED = 35
INVALID_PARK_STATE = 36
SERIAL_PORT = 0
TCP = 1


_RESPONSE_RESPONSETYPE = _descriptor.EnumDescriptor(
  name='ResponseType',
  full_name='zaber.motion.protobufs.Response.ResponseType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='OK', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ERROR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=229,
  serialized_end=262,
)
_sym_db.RegisterEnumDescriptor(_RESPONSE_RESPONSETYPE)

_AXISIDENTITY_AXISTYPE = _descriptor.EnumDescriptor(
  name='AxisType',
  full_name='zaber.motion.protobufs.AxisIdentity.AxisType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINEAR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROTARY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=458,
  serialized_end=505,
)
_sym_db.RegisterEnumDescriptor(_AXISIDENTITY_AXISTYPE)

_DEVICEMOVEREQUEST_MOVETYPE = _descriptor.EnumDescriptor(
  name='MoveType',
  full_name='zaber.motion.protobufs.DeviceMoveRequest.MoveType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ABS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3558,
  serialized_end=3613,
)
_sym_db.RegisterEnumDescriptor(_DEVICEMOVEREQUEST_MOVETYPE)

_LOCKSTEPMOVEREQUEST_MOVETYPE = _descriptor.EnumDescriptor(
  name='MoveType',
  full_name='zaber.motion.protobufs.LockstepMoveRequest.MoveType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ABS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MAX', index=3, number=3,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='MIN', index=4, number=4,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3558,
  serialized_end=3613,
)
_sym_db.RegisterEnumDescriptor(_LOCKSTEPMOVEREQUEST_MOVETYPE)

_STREAMLINEREQUEST_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='zaber.motion.protobufs.StreamLineRequest.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ABS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9311,
  serialized_end=9335,
)
_sym_db.RegisterEnumDescriptor(_STREAMLINEREQUEST_TYPE)

_STREAMARCREQUEST_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='zaber.motion.protobufs.StreamArcRequest.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ABS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9311,
  serialized_end=9335,
)
_sym_db.RegisterEnumDescriptor(_STREAMARCREQUEST_TYPE)

_STREAMCIRCLEREQUEST_TYPE = _descriptor.EnumDescriptor(
  name='Type',
  full_name='zaber.motion.protobufs.StreamCircleRequest.Type',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ABS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=9311,
  serialized_end=9335,
)
_sym_db.RegisterEnumDescriptor(_STREAMCIRCLEREQUEST_TYPE)

_BINARYDEVICEIDENTITY_DEVICETYPE = _descriptor.EnumDescriptor(
  name='DeviceType',
  full_name='zaber.motion.protobufs.BinaryDeviceIdentity.DeviceType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='LINEAR', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='ROTARY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=14124,
  serialized_end=14173,
)
_sym_db.RegisterEnumDescriptor(_BINARYDEVICEIDENTITY_DEVICETYPE)

_BINARYDEVICEMOVEREQUEST_MOVETYPE = _descriptor.EnumDescriptor(
  name='MoveType',
  full_name='zaber.motion.protobufs.BinaryDeviceMoveRequest.MoveType',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='ABS', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='REL', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='VEL', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=3558,
  serialized_end=3595,
)
_sym_db.RegisterEnumDescriptor(_BINARYDEVICEMOVEREQUEST_MOVETYPE)


_REQUEST = _descriptor.Descriptor(
  name='Request',
  full_name='zaber.motion.protobufs.Request',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='request', full_name='zaber.motion.protobufs.Request.request', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=48,
  serialized_end=74,
)


_RESPONSE = _descriptor.Descriptor(
  name='Response',
  full_name='zaber.motion.protobufs.Response',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='zaber.motion.protobufs.Response.response', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_type', full_name='zaber.motion.protobufs.Response.error_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='zaber.motion.protobufs.Response.error_message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _RESPONSE_RESPONSETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=77,
  serialized_end=262,
)


_EVENT = _descriptor.Descriptor(
  name='Event',
  full_name='zaber.motion.protobufs.Event',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='event', full_name='zaber.motion.protobufs.Event.event', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=286,
)


_EMPTYREQUEST = _descriptor.Descriptor(
  name='EmptyRequest',
  full_name='zaber.motion.protobufs.EmptyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=288,
  serialized_end=302,
)


_AXISIDENTITY = _descriptor.Descriptor(
  name='AxisIdentity',
  full_name='zaber.motion.protobufs.AxisIdentity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_peripheral', full_name='zaber.motion.protobufs.AxisIdentity.is_peripheral', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peripheral_id', full_name='zaber.motion.protobufs.AxisIdentity.peripheral_id', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peripheral_name', full_name='zaber.motion.protobufs.AxisIdentity.peripheral_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis_type', full_name='zaber.motion.protobufs.AxisIdentity.axis_type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _AXISIDENTITY_AXISTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=305,
  serialized_end=505,
)


_DEVICEIDENTITY = _descriptor.Descriptor(
  name='DeviceIdentity',
  full_name='zaber.motion.protobufs.DeviceIdentity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='zaber.motion.protobufs.DeviceIdentity.device_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='zaber.motion.protobufs.DeviceIdentity.serial_number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='zaber.motion.protobufs.DeviceIdentity.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis_count', full_name='zaber.motion.protobufs.DeviceIdentity.axis_count', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firmware_version', full_name='zaber.motion.protobufs.DeviceIdentity.firmware_version', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=508,
  serialized_end=667,
)


_FIRMWAREVERSION = _descriptor.Descriptor(
  name='FirmwareVersion',
  full_name='zaber.motion.protobufs.FirmwareVersion',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='major', full_name='zaber.motion.protobufs.FirmwareVersion.major', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='minor', full_name='zaber.motion.protobufs.FirmwareVersion.minor', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='build', full_name='zaber.motion.protobufs.FirmwareVersion.build', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=669,
  serialized_end=731,
)


_DEVICEIOINFO = _descriptor.Descriptor(
  name='DeviceIOInfo',
  full_name='zaber.motion.protobufs.DeviceIOInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='zaber.motion.protobufs.DeviceIOInfo.device_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_analog_outputs', full_name='zaber.motion.protobufs.DeviceIOInfo.number_analog_outputs', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_analog_inputs', full_name='zaber.motion.protobufs.DeviceIOInfo.number_analog_inputs', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_digital_outputs', full_name='zaber.motion.protobufs.DeviceIOInfo.number_digital_outputs', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='number_digital_inputs', full_name='zaber.motion.protobufs.DeviceIOInfo.number_digital_inputs', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=734,
  serialized_end=891,
)


_MEASUREMENT = _descriptor.Descriptor(
  name='Measurement',
  full_name='zaber.motion.protobufs.Measurement',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.Measurement.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.Measurement.unit', index=1,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=893,
  serialized_end=935,
)


_STREAMAXISDEFINITION = _descriptor.Descriptor(
  name='StreamAxisDefinition',
  full_name='zaber.motion.protobufs.StreamAxisDefinition',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='axis_number', full_name='zaber.motion.protobufs.StreamAxisDefinition.axis_number', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis_type', full_name='zaber.motion.protobufs.StreamAxisDefinition.axis_type', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=937,
  serialized_end=999,
)


_TESTREQUEST = _descriptor.Descriptor(
  name='TestRequest',
  full_name='zaber.motion.protobufs.TestRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='return_error', full_name='zaber.motion.protobufs.TestRequest.return_error', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data_ping', full_name='zaber.motion.protobufs.TestRequest.data_ping', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1001,
  serialized_end=1055,
)


_TESTRESPONSE = _descriptor.Descriptor(
  name='TestResponse',
  full_name='zaber.motion.protobufs.TestResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_pong', full_name='zaber.motion.protobufs.TestResponse.data_pong', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1057,
  serialized_end=1090,
)


_TESTRESPONSELONG = _descriptor.Descriptor(
  name='TestResponseLong',
  full_name='zaber.motion.protobufs.TestResponseLong',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data_pong', full_name='zaber.motion.protobufs.TestResponseLong.data_pong', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1092,
  serialized_end=1129,
)


_TESTEVENT = _descriptor.Descriptor(
  name='TestEvent',
  full_name='zaber.motion.protobufs.TestEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.TestEvent.data', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1131,
  serialized_end=1156,
)


_TOOLSLISTSERIALPORTSRESPONSE = _descriptor.Descriptor(
  name='ToolsListSerialPortsResponse',
  full_name='zaber.motion.protobufs.ToolsListSerialPortsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='ports', full_name='zaber.motion.protobufs.ToolsListSerialPortsResponse.ports', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1158,
  serialized_end=1203,
)


_SETDEVICEDBSOURCEREQUEST = _descriptor.Descriptor(
  name='SetDeviceDbSourceRequest',
  full_name='zaber.motion.protobufs.SetDeviceDbSourceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='source_type', full_name='zaber.motion.protobufs.SetDeviceDbSourceRequest.source_type', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='url_or_file_path', full_name='zaber.motion.protobufs.SetDeviceDbSourceRequest.url_or_file_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1205,
  serialized_end=1278,
)


_TOGGLEDEVICEDBSTOREREQUEST = _descriptor.Descriptor(
  name='ToggleDeviceDbStoreRequest',
  full_name='zaber.motion.protobufs.ToggleDeviceDbStoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='toggle_on', full_name='zaber.motion.protobufs.ToggleDeviceDbStoreRequest.toggle_on', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='store_location', full_name='zaber.motion.protobufs.ToggleDeviceDbStoreRequest.store_location', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1280,
  serialized_end=1351,
)


_OPENINTERFACEREQUEST = _descriptor.Descriptor(
  name='OpenInterfaceRequest',
  full_name='zaber.motion.protobufs.OpenInterfaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_type', full_name='zaber.motion.protobufs.OpenInterfaceRequest.interface_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_name', full_name='zaber.motion.protobufs.OpenInterfaceRequest.port_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baud_rate', full_name='zaber.motion.protobufs.OpenInterfaceRequest.baud_rate', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_name', full_name='zaber.motion.protobufs.OpenInterfaceRequest.host_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='zaber.motion.protobufs.OpenInterfaceRequest.port', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1354,
  serialized_end=1510,
)


_OPENINTERFACERESPONSE = _descriptor.Descriptor(
  name='OpenInterfaceResponse',
  full_name='zaber.motion.protobufs.OpenInterfaceResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.OpenInterfaceResponse.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1512,
  serialized_end=1557,
)


_CLOSEINTERFACEREQUEST = _descriptor.Descriptor(
  name='CloseInterfaceRequest',
  full_name='zaber.motion.protobufs.CloseInterfaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.CloseInterfaceRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1559,
  serialized_end=1604,
)


_EMPTYINTERFACEREQUEST = _descriptor.Descriptor(
  name='EmptyInterfaceRequest',
  full_name='zaber.motion.protobufs.EmptyInterfaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.EmptyInterfaceRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1606,
  serialized_end=1651,
)


_GETINTERFACETIMEOUTRESPONSE = _descriptor.Descriptor(
  name='GetInterfaceTimeoutResponse',
  full_name='zaber.motion.protobufs.GetInterfaceTimeoutResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.GetInterfaceTimeoutResponse.value', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1653,
  serialized_end=1697,
)


_SETINTERFACETIMEOUTREQUEST = _descriptor.Descriptor(
  name='SetInterfaceTimeoutRequest',
  full_name='zaber.motion.protobufs.SetInterfaceTimeoutRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.SetInterfaceTimeoutRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='zaber.motion.protobufs.SetInterfaceTimeoutRequest.timeout', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1699,
  serialized_end=1766,
)


_GETINTERFACECHECKSUMENABLEDRESPONSE = _descriptor.Descriptor(
  name='GetInterfaceChecksumEnabledResponse',
  full_name='zaber.motion.protobufs.GetInterfaceChecksumEnabledResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.GetInterfaceChecksumEnabledResponse.value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1768,
  serialized_end=1820,
)


_SETINTERFACECHECKSUMENABLEDREQUEST = _descriptor.Descriptor(
  name='SetInterfaceChecksumEnabledRequest',
  full_name='zaber.motion.protobufs.SetInterfaceChecksumEnabledRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.SetInterfaceChecksumEnabledRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_enabled', full_name='zaber.motion.protobufs.SetInterfaceChecksumEnabledRequest.is_enabled', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1822,
  serialized_end=1900,
)


_TOSTRINGREQUEST = _descriptor.Descriptor(
  name='ToStringRequest',
  full_name='zaber.motion.protobufs.ToStringRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.ToStringRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.ToStringRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.ToStringRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1902,
  serialized_end=1971,
)


_TOSTRINGRESPONSE = _descriptor.Descriptor(
  name='ToStringResponse',
  full_name='zaber.motion.protobufs.ToStringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='to_str', full_name='zaber.motion.protobufs.ToStringResponse.to_str', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1973,
  serialized_end=2007,
)


_GENERICCOMMANDREQUEST = _descriptor.Descriptor(
  name='GenericCommandRequest',
  full_name='zaber.motion.protobufs.GenericCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.GenericCommandRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.GenericCommandRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.GenericCommandRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='zaber.motion.protobufs.GenericCommandRequest.command', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='check_errors', full_name='zaber.motion.protobufs.GenericCommandRequest.check_errors', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='zaber.motion.protobufs.GenericCommandRequest.timeout', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2010,
  serialized_end=2141,
)


_GENERICCOMMANDRESPONSE = _descriptor.Descriptor(
  name='GenericCommandResponse',
  full_name='zaber.motion.protobufs.GenericCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='zaber.motion.protobufs.GenericCommandResponse.device_address', index=0,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis_number', full_name='zaber.motion.protobufs.GenericCommandResponse.axis_number', index=1,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply_flag', full_name='zaber.motion.protobufs.GenericCommandResponse.reply_flag', index=2,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='zaber.motion.protobufs.GenericCommandResponse.status', index=3,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warning_flag', full_name='zaber.motion.protobufs.GenericCommandResponse.warning_flag', index=4,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.GenericCommandResponse.data', index=5,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='zaber.motion.protobufs.GenericCommandResponse.message_type', index=6,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2144,
  serialized_end=2344,
)


_GENERICCOMMANDRESPONSECOLLECTION = _descriptor.Descriptor(
  name='GenericCommandResponseCollection',
  full_name='zaber.motion.protobufs.GenericCommandResponseCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='responses', full_name='zaber.motion.protobufs.GenericCommandResponseCollection.responses', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2346,
  serialized_end=2447,
)


_UNKNOWNRESPONSEEVENT = _descriptor.Descriptor(
  name='UnknownResponseEvent',
  full_name='zaber.motion.protobufs.UnknownResponseEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.UnknownResponseEvent.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_address', full_name='zaber.motion.protobufs.UnknownResponseEvent.device_address', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis_number', full_name='zaber.motion.protobufs.UnknownResponseEvent.axis_number', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='reply_flag', full_name='zaber.motion.protobufs.UnknownResponseEvent.reply_flag', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='zaber.motion.protobufs.UnknownResponseEvent.status', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warning_flag', full_name='zaber.motion.protobufs.UnknownResponseEvent.warning_flag', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.UnknownResponseEvent.data', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='message_type', full_name='zaber.motion.protobufs.UnknownResponseEvent.message_type', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2450,
  serialized_end=2670,
)


_ALERTEVENT = _descriptor.Descriptor(
  name='AlertEvent',
  full_name='zaber.motion.protobufs.AlertEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.AlertEvent.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_address', full_name='zaber.motion.protobufs.AlertEvent.device_address', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis_number', full_name='zaber.motion.protobufs.AlertEvent.axis_number', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='status', full_name='zaber.motion.protobufs.AlertEvent.status', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='warning_flag', full_name='zaber.motion.protobufs.AlertEvent.warning_flag', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.AlertEvent.data', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2673,
  serialized_end=2804,
)


_DISCONNECTEDEVENT = _descriptor.Descriptor(
  name='DisconnectedEvent',
  full_name='zaber.motion.protobufs.DisconnectedEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DisconnectedEvent.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_type', full_name='zaber.motion.protobufs.DisconnectedEvent.error_type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='error_message', full_name='zaber.motion.protobufs.DisconnectedEvent.error_message', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2806,
  serialized_end=2922,
)


_DEVICERENUMBERREQUEST = _descriptor.Descriptor(
  name='DeviceRenumberRequest',
  full_name='zaber.motion.protobufs.DeviceRenumberRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceRenumberRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='first_address', full_name='zaber.motion.protobufs.DeviceRenumberRequest.first_address', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2924,
  serialized_end=2992,
)


_DEVICERENUMBERRESPONSE = _descriptor.Descriptor(
  name='DeviceRenumberResponse',
  full_name='zaber.motion.protobufs.DeviceRenumberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='number_devices', full_name='zaber.motion.protobufs.DeviceRenumberResponse.number_devices', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2994,
  serialized_end=3042,
)


_DEVICEDETECTREQUEST = _descriptor.Descriptor(
  name='DeviceDetectRequest',
  full_name='zaber.motion.protobufs.DeviceDetectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceDetectRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identify_devices', full_name='zaber.motion.protobufs.DeviceDetectRequest.identify_devices', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3044,
  serialized_end=3113,
)


_DEVICEDETECTRESPONSE = _descriptor.Descriptor(
  name='DeviceDetectResponse',
  full_name='zaber.motion.protobufs.DeviceDetectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='devices', full_name='zaber.motion.protobufs.DeviceDetectResponse.devices', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3115,
  serialized_end=3154,
)


_DEVICEHOMEREQUEST = _descriptor.Descriptor(
  name='DeviceHomeRequest',
  full_name='zaber.motion.protobufs.DeviceHomeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceHomeRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceHomeRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceHomeRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait_until_idle', full_name='zaber.motion.protobufs.DeviceHomeRequest.wait_until_idle', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3156,
  serialized_end=3252,
)


_DEVICEWAITUNTILIDLEREQUEST = _descriptor.Descriptor(
  name='DeviceWaitUntilIdleRequest',
  full_name='zaber.motion.protobufs.DeviceWaitUntilIdleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceWaitUntilIdleRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceWaitUntilIdleRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceWaitUntilIdleRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throw_error_on_fault', full_name='zaber.motion.protobufs.DeviceWaitUntilIdleRequest.throw_error_on_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3254,
  serialized_end=3364,
)


_DEVICEMOVEREQUEST = _descriptor.Descriptor(
  name='DeviceMoveRequest',
  full_name='zaber.motion.protobufs.DeviceMoveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceMoveRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceMoveRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceMoveRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait_until_idle', full_name='zaber.motion.protobufs.DeviceMoveRequest.wait_until_idle', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='zaber.motion.protobufs.DeviceMoveRequest.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arg', full_name='zaber.motion.protobufs.DeviceMoveRequest.arg', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.DeviceMoveRequest.unit', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DEVICEMOVEREQUEST_MOVETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3367,
  serialized_end=3613,
)


_DEVICESTOPREQUEST = _descriptor.Descriptor(
  name='DeviceStopRequest',
  full_name='zaber.motion.protobufs.DeviceStopRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceStopRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceStopRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceStopRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait_until_idle', full_name='zaber.motion.protobufs.DeviceStopRequest.wait_until_idle', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3615,
  serialized_end=3711,
)


_DEVICEIDENTIFYREQUEST = _descriptor.Descriptor(
  name='DeviceIdentifyRequest',
  full_name='zaber.motion.protobufs.DeviceIdentifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceIdentifyRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceIdentifyRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3713,
  serialized_end=3774,
)


_DEVICEGETIDENTITYREQUEST = _descriptor.Descriptor(
  name='DeviceGetIdentityRequest',
  full_name='zaber.motion.protobufs.DeviceGetIdentityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceGetIdentityRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceGetIdentityRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3776,
  serialized_end=3840,
)


_DEVICEGETIDENTITYRESPONSE = _descriptor.Descriptor(
  name='DeviceGetIdentityResponse',
  full_name='zaber.motion.protobufs.DeviceGetIdentityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identity', full_name='zaber.motion.protobufs.DeviceGetIdentityResponse.identity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3842,
  serialized_end=3927,
)


_DEVICEGETISIDENTIFIEDREQUEST = _descriptor.Descriptor(
  name='DeviceGetIsIdentifiedRequest',
  full_name='zaber.motion.protobufs.DeviceGetIsIdentifiedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceGetIsIdentifiedRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceGetIsIdentifiedRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3929,
  serialized_end=3997,
)


_DEVICEGETISIDENTIFIEDRESPONSE = _descriptor.Descriptor(
  name='DeviceGetIsIdentifiedResponse',
  full_name='zaber.motion.protobufs.DeviceGetIsIdentifiedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_identified', full_name='zaber.motion.protobufs.DeviceGetIsIdentifiedResponse.is_identified', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3999,
  serialized_end=4053,
)


_DEVICEGETAXISIDENTITYREQUEST = _descriptor.Descriptor(
  name='DeviceGetAxisIdentityRequest',
  full_name='zaber.motion.protobufs.DeviceGetAxisIdentityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceGetAxisIdentityRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceGetAxisIdentityRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceGetAxisIdentityRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4055,
  serialized_end=4137,
)


_DEVICEGETAXISIDENTITYRESPONSE = _descriptor.Descriptor(
  name='DeviceGetAxisIdentityResponse',
  full_name='zaber.motion.protobufs.DeviceGetAxisIdentityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identity', full_name='zaber.motion.protobufs.DeviceGetAxisIdentityResponse.identity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4139,
  serialized_end=4226,
)


_DEVICEISBUSYREQUEST = _descriptor.Descriptor(
  name='DeviceIsBusyRequest',
  full_name='zaber.motion.protobufs.DeviceIsBusyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceIsBusyRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceIsBusyRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceIsBusyRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4228,
  serialized_end=4301,
)


_DEVICEISBUSYRESPONSE = _descriptor.Descriptor(
  name='DeviceIsBusyResponse',
  full_name='zaber.motion.protobufs.DeviceIsBusyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_busy', full_name='zaber.motion.protobufs.DeviceIsBusyResponse.is_busy', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4303,
  serialized_end=4342,
)


_DEVICEGETWARNINGSREQUEST = _descriptor.Descriptor(
  name='DeviceGetWarningsRequest',
  full_name='zaber.motion.protobufs.DeviceGetWarningsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceGetWarningsRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceGetWarningsRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceGetWarningsRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='clear', full_name='zaber.motion.protobufs.DeviceGetWarningsRequest.clear', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4344,
  serialized_end=4437,
)


_DEVICEGETWARNINGSRESPONSE = _descriptor.Descriptor(
  name='DeviceGetWarningsResponse',
  full_name='zaber.motion.protobufs.DeviceGetWarningsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='flags', full_name='zaber.motion.protobufs.DeviceGetWarningsResponse.flags', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4439,
  serialized_end=4481,
)


_DEVICEGETALLDIGITALIOREQUEST = _descriptor.Descriptor(
  name='DeviceGetAllDigitalIORequest',
  full_name='zaber.motion.protobufs.DeviceGetAllDigitalIORequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceGetAllDigitalIORequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceGetAllDigitalIORequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_type', full_name='zaber.motion.protobufs.DeviceGetAllDigitalIORequest.channel_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4483,
  serialized_end=4573,
)


_DEVICEGETALLDIGITALIORESPONSE = _descriptor.Descriptor(
  name='DeviceGetAllDigitalIOResponse',
  full_name='zaber.motion.protobufs.DeviceGetAllDigitalIOResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='zaber.motion.protobufs.DeviceGetAllDigitalIOResponse.values', index=0,
      number=1, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4575,
  serialized_end=4622,
)


_DEVICEGETALLANALOGIOREQUEST = _descriptor.Descriptor(
  name='DeviceGetAllAnalogIORequest',
  full_name='zaber.motion.protobufs.DeviceGetAllAnalogIORequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceGetAllAnalogIORequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceGetAllAnalogIORequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_type', full_name='zaber.motion.protobufs.DeviceGetAllAnalogIORequest.channel_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4624,
  serialized_end=4713,
)


_DEVICEGETALLANALOGIORESPONSE = _descriptor.Descriptor(
  name='DeviceGetAllAnalogIOResponse',
  full_name='zaber.motion.protobufs.DeviceGetAllAnalogIOResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='values', full_name='zaber.motion.protobufs.DeviceGetAllAnalogIOResponse.values', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4715,
  serialized_end=4761,
)


_DEVICEGETDIGITALIOREQUEST = _descriptor.Descriptor(
  name='DeviceGetDigitalIORequest',
  full_name='zaber.motion.protobufs.DeviceGetDigitalIORequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceGetDigitalIORequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceGetDigitalIORequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_type', full_name='zaber.motion.protobufs.DeviceGetDigitalIORequest.channel_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='zaber.motion.protobufs.DeviceGetDigitalIORequest.channel_number', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4763,
  serialized_end=4874,
)


_DEVICEGETDIGITALIORESPONSE = _descriptor.Descriptor(
  name='DeviceGetDigitalIOResponse',
  full_name='zaber.motion.protobufs.DeviceGetDigitalIOResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.DeviceGetDigitalIOResponse.value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4876,
  serialized_end=4919,
)


_DEVICEGETANALOGIOREQUEST = _descriptor.Descriptor(
  name='DeviceGetAnalogIORequest',
  full_name='zaber.motion.protobufs.DeviceGetAnalogIORequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceGetAnalogIORequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceGetAnalogIORequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_type', full_name='zaber.motion.protobufs.DeviceGetAnalogIORequest.channel_type', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='zaber.motion.protobufs.DeviceGetAnalogIORequest.channel_number', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4921,
  serialized_end=5031,
)


_DEVICEGETANALOGIORESPONSE = _descriptor.Descriptor(
  name='DeviceGetAnalogIOResponse',
  full_name='zaber.motion.protobufs.DeviceGetAnalogIOResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.DeviceGetAnalogIOResponse.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5033,
  serialized_end=5075,
)


_DEVICESETALLDIGITALOUTPUTSREQUEST = _descriptor.Descriptor(
  name='DeviceSetAllDigitalOutputsRequest',
  full_name='zaber.motion.protobufs.DeviceSetAllDigitalOutputsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceSetAllDigitalOutputsRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceSetAllDigitalOutputsRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='zaber.motion.protobufs.DeviceSetAllDigitalOutputsRequest.values', index=2,
      number=3, type=8, cpp_type=7, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5077,
  serialized_end=5166,
)


_DEVICESETALLANALOGOUTPUTSREQUEST = _descriptor.Descriptor(
  name='DeviceSetAllAnalogOutputsRequest',
  full_name='zaber.motion.protobufs.DeviceSetAllAnalogOutputsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceSetAllAnalogOutputsRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceSetAllAnalogOutputsRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='values', full_name='zaber.motion.protobufs.DeviceSetAllAnalogOutputsRequest.values', index=2,
      number=3, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5168,
  serialized_end=5256,
)


_DEVICESETDIGITALOUTPUTREQUEST = _descriptor.Descriptor(
  name='DeviceSetDigitalOutputRequest',
  full_name='zaber.motion.protobufs.DeviceSetDigitalOutputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceSetDigitalOutputRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceSetDigitalOutputRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='zaber.motion.protobufs.DeviceSetDigitalOutputRequest.channel_number', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.DeviceSetDigitalOutputRequest.value', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5258,
  serialized_end=5366,
)


_DEVICESETANALOGOUTPUTREQUEST = _descriptor.Descriptor(
  name='DeviceSetAnalogOutputRequest',
  full_name='zaber.motion.protobufs.DeviceSetAnalogOutputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceSetAnalogOutputRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceSetAnalogOutputRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='zaber.motion.protobufs.DeviceSetAnalogOutputRequest.channel_number', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.DeviceSetAnalogOutputRequest.value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5368,
  serialized_end=5475,
)


_DEVICEGETIOCHANNELSINFOREQUEST = _descriptor.Descriptor(
  name='DeviceGetIOChannelsInfoRequest',
  full_name='zaber.motion.protobufs.DeviceGetIOChannelsInfoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceGetIOChannelsInfoRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceGetIOChannelsInfoRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5477,
  serialized_end=5547,
)


_SETLOGOUTPUTREQUEST = _descriptor.Descriptor(
  name='SetLogOutputRequest',
  full_name='zaber.motion.protobufs.SetLogOutputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='zaber.motion.protobufs.SetLogOutputRequest.mode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='file_path', full_name='zaber.motion.protobufs.SetLogOutputRequest.file_path', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5549,
  serialized_end=5603,
)


_DEVICEGETSETTINGREQUEST = _descriptor.Descriptor(
  name='DeviceGetSettingRequest',
  full_name='zaber.motion.protobufs.DeviceGetSettingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceGetSettingRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceGetSettingRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceGetSettingRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setting', full_name='zaber.motion.protobufs.DeviceGetSettingRequest.setting', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.DeviceGetSettingRequest.unit', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5605,
  serialized_end=5713,
)


_DEVICEGETSETTINGRESPONSE = _descriptor.Descriptor(
  name='DeviceGetSettingResponse',
  full_name='zaber.motion.protobufs.DeviceGetSettingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.DeviceGetSettingResponse.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5715,
  serialized_end=5756,
)


_DEVICECONVERTSETTINGREQUEST = _descriptor.Descriptor(
  name='DeviceConvertSettingRequest',
  full_name='zaber.motion.protobufs.DeviceConvertSettingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceConvertSettingRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceConvertSettingRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceConvertSettingRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setting', full_name='zaber.motion.protobufs.DeviceConvertSettingRequest.setting', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.DeviceConvertSettingRequest.unit', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.DeviceConvertSettingRequest.value', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_native', full_name='zaber.motion.protobufs.DeviceConvertSettingRequest.from_native', index=6,
      number=7, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5759,
  serialized_end=5907,
)


_DEVICECONVERTSETTINGRESPONSE = _descriptor.Descriptor(
  name='DeviceConvertSettingResponse',
  full_name='zaber.motion.protobufs.DeviceConvertSettingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.DeviceConvertSettingResponse.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5909,
  serialized_end=5954,
)


_DEVICESETSETTINGREQUEST = _descriptor.Descriptor(
  name='DeviceSetSettingRequest',
  full_name='zaber.motion.protobufs.DeviceSetSettingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceSetSettingRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceSetSettingRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceSetSettingRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setting', full_name='zaber.motion.protobufs.DeviceSetSettingRequest.setting', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.DeviceSetSettingRequest.value', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.DeviceSetSettingRequest.unit', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=5956,
  serialized_end=6079,
)


_PREPARECOMMANDREQUEST = _descriptor.Descriptor(
  name='PrepareCommandRequest',
  full_name='zaber.motion.protobufs.PrepareCommandRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.PrepareCommandRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.PrepareCommandRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.PrepareCommandRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command_template', full_name='zaber.motion.protobufs.PrepareCommandRequest.command_template', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='zaber.motion.protobufs.PrepareCommandRequest.parameters', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6082,
  serialized_end=6240,
)


_PREPARECOMMANDRESPONSE = _descriptor.Descriptor(
  name='PrepareCommandResponse',
  full_name='zaber.motion.protobufs.PrepareCommandResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='zaber.motion.protobufs.PrepareCommandResponse.command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6242,
  serialized_end=6283,
)


_DEVICEPARKREQUEST = _descriptor.Descriptor(
  name='DeviceParkRequest',
  full_name='zaber.motion.protobufs.DeviceParkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.DeviceParkRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.DeviceParkRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis', full_name='zaber.motion.protobufs.DeviceParkRequest.axis', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6285,
  serialized_end=6356,
)


_DEVICEISPARKEDRESPONSE = _descriptor.Descriptor(
  name='DeviceIsParkedResponse',
  full_name='zaber.motion.protobufs.DeviceIsParkedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_parked', full_name='zaber.motion.protobufs.DeviceIsParkedResponse.is_parked', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6358,
  serialized_end=6401,
)


_LOCKSTEPENABLEREQUEST = _descriptor.Descriptor(
  name='LockstepEnableRequest',
  full_name='zaber.motion.protobufs.LockstepEnableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.LockstepEnableRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.LockstepEnableRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep_group_id', full_name='zaber.motion.protobufs.LockstepEnableRequest.lockstep_group_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axes', full_name='zaber.motion.protobufs.LockstepEnableRequest.axes', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6403,
  serialized_end=6505,
)


_LOCKSTEPDISABLEREQUEST = _descriptor.Descriptor(
  name='LockstepDisableRequest',
  full_name='zaber.motion.protobufs.LockstepDisableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.LockstepDisableRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.LockstepDisableRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep_group_id', full_name='zaber.motion.protobufs.LockstepDisableRequest.lockstep_group_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait_until_idle', full_name='zaber.motion.protobufs.LockstepDisableRequest.wait_until_idle', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6507,
  serialized_end=6621,
)


_LOCKSTEPSTOPREQUEST = _descriptor.Descriptor(
  name='LockstepStopRequest',
  full_name='zaber.motion.protobufs.LockstepStopRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.LockstepStopRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.LockstepStopRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep_group_id', full_name='zaber.motion.protobufs.LockstepStopRequest.lockstep_group_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait_until_idle', full_name='zaber.motion.protobufs.LockstepStopRequest.wait_until_idle', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6623,
  serialized_end=6734,
)


_LOCKSTEPHOMEREQUEST = _descriptor.Descriptor(
  name='LockstepHomeRequest',
  full_name='zaber.motion.protobufs.LockstepHomeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.LockstepHomeRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.LockstepHomeRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep_group_id', full_name='zaber.motion.protobufs.LockstepHomeRequest.lockstep_group_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait_until_idle', full_name='zaber.motion.protobufs.LockstepHomeRequest.wait_until_idle', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6736,
  serialized_end=6847,
)


_LOCKSTEPMOVEREQUEST = _descriptor.Descriptor(
  name='LockstepMoveRequest',
  full_name='zaber.motion.protobufs.LockstepMoveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.LockstepMoveRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.LockstepMoveRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep_group_id', full_name='zaber.motion.protobufs.LockstepMoveRequest.lockstep_group_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='wait_until_idle', full_name='zaber.motion.protobufs.LockstepMoveRequest.wait_until_idle', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='zaber.motion.protobufs.LockstepMoveRequest.type', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arg', full_name='zaber.motion.protobufs.LockstepMoveRequest.arg', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.LockstepMoveRequest.unit', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LOCKSTEPMOVEREQUEST_MOVETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=6850,
  serialized_end=7113,
)


_LOCKSTEPWAITUNTILIDLEREQUEST = _descriptor.Descriptor(
  name='LockstepWaitUntilIdleRequest',
  full_name='zaber.motion.protobufs.LockstepWaitUntilIdleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.LockstepWaitUntilIdleRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.LockstepWaitUntilIdleRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep_group_id', full_name='zaber.motion.protobufs.LockstepWaitUntilIdleRequest.lockstep_group_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throw_error_on_fault', full_name='zaber.motion.protobufs.LockstepWaitUntilIdleRequest.throw_error_on_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7115,
  serialized_end=7240,
)


_LOCKSTEPISBUSYREQUEST = _descriptor.Descriptor(
  name='LockstepIsBusyRequest',
  full_name='zaber.motion.protobufs.LockstepIsBusyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.LockstepIsBusyRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.LockstepIsBusyRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep_group_id', full_name='zaber.motion.protobufs.LockstepIsBusyRequest.lockstep_group_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7242,
  serialized_end=7330,
)


_LOCKSTEPISBUSYRESPONSE = _descriptor.Descriptor(
  name='LockstepIsBusyResponse',
  full_name='zaber.motion.protobufs.LockstepIsBusyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_busy', full_name='zaber.motion.protobufs.LockstepIsBusyResponse.is_busy', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7332,
  serialized_end=7373,
)


_LOCKSTEPGETAXESREQUEST = _descriptor.Descriptor(
  name='LockstepGetAxesRequest',
  full_name='zaber.motion.protobufs.LockstepGetAxesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.LockstepGetAxesRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.LockstepGetAxesRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep_group_id', full_name='zaber.motion.protobufs.LockstepGetAxesRequest.lockstep_group_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7375,
  serialized_end=7464,
)


_LOCKSTEPAXES = _descriptor.Descriptor(
  name='LockstepAxes',
  full_name='zaber.motion.protobufs.LockstepAxes',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='axis_1', full_name='zaber.motion.protobufs.LockstepAxes.axis_1', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis_2', full_name='zaber.motion.protobufs.LockstepAxes.axis_2', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis_3', full_name='zaber.motion.protobufs.LockstepAxes.axis_3', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axis_4', full_name='zaber.motion.protobufs.LockstepAxes.axis_4', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7466,
  serialized_end=7544,
)


_LOCKSTEPGETAXESRESPONSE = _descriptor.Descriptor(
  name='LockstepGetAxesResponse',
  full_name='zaber.motion.protobufs.LockstepGetAxesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='axes', full_name='zaber.motion.protobufs.LockstepGetAxesResponse.axes', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7546,
  serialized_end=7623,
)


_LOCKSTEPGETTWISTREQUEST = _descriptor.Descriptor(
  name='LockstepGetTwistRequest',
  full_name='zaber.motion.protobufs.LockstepGetTwistRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.LockstepGetTwistRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.LockstepGetTwistRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep_group_id', full_name='zaber.motion.protobufs.LockstepGetTwistRequest.lockstep_group_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.LockstepGetTwistRequest.unit', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7625,
  serialized_end=7729,
)


_LOCKSTEPGETTWISTRESPONSE = _descriptor.Descriptor(
  name='LockstepGetTwistResponse',
  full_name='zaber.motion.protobufs.LockstepGetTwistResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='twist', full_name='zaber.motion.protobufs.LockstepGetTwistResponse.twist', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7731,
  serialized_end=7772,
)


_LOCKSTEPGETTWISTSRESPONSE = _descriptor.Descriptor(
  name='LockstepGetTwistsResponse',
  full_name='zaber.motion.protobufs.LockstepGetTwistsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='twists', full_name='zaber.motion.protobufs.LockstepGetTwistsResponse.twists', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7774,
  serialized_end=7817,
)


_LOCKSTEPGETOFFSETREQUEST = _descriptor.Descriptor(
  name='LockstepGetOffsetRequest',
  full_name='zaber.motion.protobufs.LockstepGetOffsetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.LockstepGetOffsetRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.LockstepGetOffsetRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep_group_id', full_name='zaber.motion.protobufs.LockstepGetOffsetRequest.lockstep_group_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.LockstepGetOffsetRequest.unit', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7819,
  serialized_end=7924,
)


_LOCKSTEPGETOFFSETRESPONSE = _descriptor.Descriptor(
  name='LockstepGetOffsetResponse',
  full_name='zaber.motion.protobufs.LockstepGetOffsetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='zaber.motion.protobufs.LockstepGetOffsetResponse.offset', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7926,
  serialized_end=7969,
)


_LOCKSTEPGETOFFSETSRESPONSE = _descriptor.Descriptor(
  name='LockstepGetOffsetsResponse',
  full_name='zaber.motion.protobufs.LockstepGetOffsetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='offsets', full_name='zaber.motion.protobufs.LockstepGetOffsetsResponse.offsets', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=7971,
  serialized_end=8016,
)


_LOCKSTEPISENABLEDREQUEST = _descriptor.Descriptor(
  name='LockstepIsEnabledRequest',
  full_name='zaber.motion.protobufs.LockstepIsEnabledRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.LockstepIsEnabledRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.LockstepIsEnabledRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep_group_id', full_name='zaber.motion.protobufs.LockstepIsEnabledRequest.lockstep_group_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8018,
  serialized_end=8109,
)


_LOCKSTEPISENABLEDRESPONSE = _descriptor.Descriptor(
  name='LockstepIsEnabledResponse',
  full_name='zaber.motion.protobufs.LockstepIsEnabledResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_enabled', full_name='zaber.motion.protobufs.LockstepIsEnabledResponse.is_enabled', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8111,
  serialized_end=8158,
)


_LOCKSTEPTOSTRINGREQUEST = _descriptor.Descriptor(
  name='LockstepToStringRequest',
  full_name='zaber.motion.protobufs.LockstepToStringRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.LockstepToStringRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.LockstepToStringRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='lockstep_group_id', full_name='zaber.motion.protobufs.LockstepToStringRequest.lockstep_group_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8160,
  serialized_end=8250,
)


_LOCKSTEPTOSTRINGRESPONSE = _descriptor.Descriptor(
  name='LockstepToStringResponse',
  full_name='zaber.motion.protobufs.LockstepToStringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='to_str', full_name='zaber.motion.protobufs.LockstepToStringResponse.to_str', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8252,
  serialized_end=8294,
)


_STREAMSETUPLIVEREQUEST = _descriptor.Descriptor(
  name='StreamSetupLiveRequest',
  full_name='zaber.motion.protobufs.StreamSetupLiveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamSetupLiveRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamSetupLiveRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamSetupLiveRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axes', full_name='zaber.motion.protobufs.StreamSetupLiveRequest.axes', index=3,
      number=4, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8296,
  serialized_end=8391,
)


_STREAMSETUPLIVECOMPOSITEREQUEST = _descriptor.Descriptor(
  name='StreamSetupLiveCompositeRequest',
  full_name='zaber.motion.protobufs.StreamSetupLiveCompositeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamSetupLiveCompositeRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamSetupLiveCompositeRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamSetupLiveCompositeRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axes', full_name='zaber.motion.protobufs.StreamSetupLiveCompositeRequest.axes', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8394,
  serialized_end=8544,
)


_STREAMSETUPSTOREREQUEST = _descriptor.Descriptor(
  name='StreamSetupStoreRequest',
  full_name='zaber.motion.protobufs.StreamSetupStoreRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamSetupStoreRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamSetupStoreRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamSetupStoreRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_buffer', full_name='zaber.motion.protobufs.StreamSetupStoreRequest.stream_buffer', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axes', full_name='zaber.motion.protobufs.StreamSetupStoreRequest.axes', index=4,
      number=5, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8546,
  serialized_end=8665,
)


_STREAMSETUPSTORECOMPOSITEREQUEST = _descriptor.Descriptor(
  name='StreamSetupStoreCompositeRequest',
  full_name='zaber.motion.protobufs.StreamSetupStoreCompositeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamSetupStoreCompositeRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamSetupStoreCompositeRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamSetupStoreCompositeRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_buffer', full_name='zaber.motion.protobufs.StreamSetupStoreCompositeRequest.stream_buffer', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axes', full_name='zaber.motion.protobufs.StreamSetupStoreCompositeRequest.axes', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8668,
  serialized_end=8842,
)


_STREAMSETUPSTOREARBITRARYAXESREQUEST = _descriptor.Descriptor(
  name='StreamSetupStoreArbitraryAxesRequest',
  full_name='zaber.motion.protobufs.StreamSetupStoreArbitraryAxesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamSetupStoreArbitraryAxesRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamSetupStoreArbitraryAxesRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamSetupStoreArbitraryAxesRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_buffer', full_name='zaber.motion.protobufs.StreamSetupStoreArbitraryAxesRequest.stream_buffer', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='axes_count', full_name='zaber.motion.protobufs.StreamSetupStoreArbitraryAxesRequest.axes_count', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8845,
  serialized_end=8983,
)


_STREAMCALLREQUEST = _descriptor.Descriptor(
  name='StreamCallRequest',
  full_name='zaber.motion.protobufs.StreamCallRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamCallRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamCallRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamCallRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_buffer', full_name='zaber.motion.protobufs.StreamCallRequest.stream_buffer', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=8985,
  serialized_end=9084,
)


_STREAMLINEREQUEST = _descriptor.Descriptor(
  name='StreamLineRequest',
  full_name='zaber.motion.protobufs.StreamLineRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamLineRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamLineRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamLineRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='zaber.motion.protobufs.StreamLineRequest.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='endpoint', full_name='zaber.motion.protobufs.StreamLineRequest.endpoint', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_axes_indices', full_name='zaber.motion.protobufs.StreamLineRequest.target_axes_indices', index=5,
      number=6, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STREAMLINEREQUEST_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9087,
  serialized_end=9335,
)


_STREAMARCREQUEST = _descriptor.Descriptor(
  name='StreamArcRequest',
  full_name='zaber.motion.protobufs.StreamArcRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamArcRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamArcRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamArcRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='zaber.motion.protobufs.StreamArcRequest.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rotation_direction', full_name='zaber.motion.protobufs.StreamArcRequest.rotation_direction', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='center_x', full_name='zaber.motion.protobufs.StreamArcRequest.center_x', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='center_y', full_name='zaber.motion.protobufs.StreamArcRequest.center_y', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_x', full_name='zaber.motion.protobufs.StreamArcRequest.end_x', index=7,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='end_y', full_name='zaber.motion.protobufs.StreamArcRequest.end_y', index=8,
      number=9, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_axes_indices', full_name='zaber.motion.protobufs.StreamArcRequest.target_axes_indices', index=9,
      number=10, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STREAMARCREQUEST_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9338,
  serialized_end=9771,
)


_STREAMCIRCLEREQUEST = _descriptor.Descriptor(
  name='StreamCircleRequest',
  full_name='zaber.motion.protobufs.StreamCircleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamCircleRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamCircleRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamCircleRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='zaber.motion.protobufs.StreamCircleRequest.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rotation_direction', full_name='zaber.motion.protobufs.StreamCircleRequest.rotation_direction', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='center_x', full_name='zaber.motion.protobufs.StreamCircleRequest.center_x', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='center_y', full_name='zaber.motion.protobufs.StreamCircleRequest.center_y', index=6,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='target_axes_indices', full_name='zaber.motion.protobufs.StreamCircleRequest.target_axes_indices', index=7,
      number=8, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _STREAMCIRCLEREQUEST_TYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=9774,
  serialized_end=10109,
)


_STREAMWAITDIGITALINPUTREQUEST = _descriptor.Descriptor(
  name='StreamWaitDigitalInputRequest',
  full_name='zaber.motion.protobufs.StreamWaitDigitalInputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamWaitDigitalInputRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamWaitDigitalInputRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamWaitDigitalInputRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='zaber.motion.protobufs.StreamWaitDigitalInputRequest.channel_number', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.StreamWaitDigitalInputRequest.value', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10111,
  serialized_end=10238,
)


_STREAMWAITANALOGINPUTREQUEST = _descriptor.Descriptor(
  name='StreamWaitAnalogInputRequest',
  full_name='zaber.motion.protobufs.StreamWaitAnalogInputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamWaitAnalogInputRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamWaitAnalogInputRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamWaitAnalogInputRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='zaber.motion.protobufs.StreamWaitAnalogInputRequest.channel_number', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='condition', full_name='zaber.motion.protobufs.StreamWaitAnalogInputRequest.condition', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.StreamWaitAnalogInputRequest.value', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10241,
  serialized_end=10386,
)


_STREAMSETDIGITALOUTPUTREQUEST = _descriptor.Descriptor(
  name='StreamSetDigitalOutputRequest',
  full_name='zaber.motion.protobufs.StreamSetDigitalOutputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamSetDigitalOutputRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamSetDigitalOutputRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamSetDigitalOutputRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='zaber.motion.protobufs.StreamSetDigitalOutputRequest.channel_number', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.StreamSetDigitalOutputRequest.value', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10388,
  serialized_end=10515,
)


_STREAMSETANALOGOUTPUTREQUEST = _descriptor.Descriptor(
  name='StreamSetAnalogOutputRequest',
  full_name='zaber.motion.protobufs.StreamSetAnalogOutputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamSetAnalogOutputRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamSetAnalogOutputRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamSetAnalogOutputRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='zaber.motion.protobufs.StreamSetAnalogOutputRequest.channel_number', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.StreamSetAnalogOutputRequest.value', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10517,
  serialized_end=10643,
)


_STREAMTOGGLEDIGITALOUTPUTREQUEST = _descriptor.Descriptor(
  name='StreamToggleDigitalOutputRequest',
  full_name='zaber.motion.protobufs.StreamToggleDigitalOutputRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamToggleDigitalOutputRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamToggleDigitalOutputRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamToggleDigitalOutputRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='channel_number', full_name='zaber.motion.protobufs.StreamToggleDigitalOutputRequest.channel_number', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10645,
  serialized_end=10760,
)


_STREAMWAITREQUEST = _descriptor.Descriptor(
  name='StreamWaitRequest',
  full_name='zaber.motion.protobufs.StreamWaitRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamWaitRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamWaitRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamWaitRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='time', full_name='zaber.motion.protobufs.StreamWaitRequest.time', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.StreamWaitRequest.unit', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10762,
  serialized_end=10866,
)


_STREAMWAITUNTILIDLEREQUEST = _descriptor.Descriptor(
  name='StreamWaitUntilIdleRequest',
  full_name='zaber.motion.protobufs.StreamWaitUntilIdleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamWaitUntilIdleRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamWaitUntilIdleRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamWaitUntilIdleRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='throw_error_on_fault', full_name='zaber.motion.protobufs.StreamWaitUntilIdleRequest.throw_error_on_fault', index=3,
      number=4, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10868,
  serialized_end=10983,
)


_STREAMCORKREQUEST = _descriptor.Descriptor(
  name='StreamCorkRequest',
  full_name='zaber.motion.protobufs.StreamCorkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamCorkRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamCorkRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamCorkRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=10985,
  serialized_end=11061,
)


_STREAMUNCORKREQUEST = _descriptor.Descriptor(
  name='StreamUncorkRequest',
  full_name='zaber.motion.protobufs.StreamUncorkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamUncorkRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamUncorkRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamUncorkRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11063,
  serialized_end=11141,
)


_STREAMISBUSYREQUEST = _descriptor.Descriptor(
  name='StreamIsBusyRequest',
  full_name='zaber.motion.protobufs.StreamIsBusyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamIsBusyRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamIsBusyRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamIsBusyRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11143,
  serialized_end=11221,
)


_STREAMISBUSYRESPONSE = _descriptor.Descriptor(
  name='StreamIsBusyResponse',
  full_name='zaber.motion.protobufs.StreamIsBusyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_busy', full_name='zaber.motion.protobufs.StreamIsBusyResponse.is_busy', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11223,
  serialized_end=11262,
)


_STREAMGETAXESREQUEST = _descriptor.Descriptor(
  name='StreamGetAxesRequest',
  full_name='zaber.motion.protobufs.StreamGetAxesRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamGetAxesRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamGetAxesRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamGetAxesRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11264,
  serialized_end=11343,
)


_STREAMGETAXESRESPONSE = _descriptor.Descriptor(
  name='StreamGetAxesResponse',
  full_name='zaber.motion.protobufs.StreamGetAxesResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='axes', full_name='zaber.motion.protobufs.StreamGetAxesResponse.axes', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11345,
  serialized_end=11428,
)


_STREAMGETMODEREQUEST = _descriptor.Descriptor(
  name='StreamGetModeRequest',
  full_name='zaber.motion.protobufs.StreamGetModeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamGetModeRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamGetModeRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamGetModeRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11430,
  serialized_end=11509,
)


_STREAMGETMODERESPONSE = _descriptor.Descriptor(
  name='StreamGetModeResponse',
  full_name='zaber.motion.protobufs.StreamGetModeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='mode', full_name='zaber.motion.protobufs.StreamGetModeResponse.mode', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11511,
  serialized_end=11548,
)


_STREAMGETMAXSPEEDREQUEST = _descriptor.Descriptor(
  name='StreamGetMaxSpeedRequest',
  full_name='zaber.motion.protobufs.StreamGetMaxSpeedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamGetMaxSpeedRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamGetMaxSpeedRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamGetMaxSpeedRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.StreamGetMaxSpeedRequest.unit', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11550,
  serialized_end=11647,
)


_STREAMGETMAXSPEEDRESPONSE = _descriptor.Descriptor(
  name='StreamGetMaxSpeedResponse',
  full_name='zaber.motion.protobufs.StreamGetMaxSpeedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_speed', full_name='zaber.motion.protobufs.StreamGetMaxSpeedResponse.max_speed', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11649,
  serialized_end=11695,
)


_STREAMSETMAXSPEEDREQUEST = _descriptor.Descriptor(
  name='StreamSetMaxSpeedRequest',
  full_name='zaber.motion.protobufs.StreamSetMaxSpeedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamSetMaxSpeedRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamSetMaxSpeedRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamSetMaxSpeedRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_speed', full_name='zaber.motion.protobufs.StreamSetMaxSpeedRequest.max_speed', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.StreamSetMaxSpeedRequest.unit', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11697,
  serialized_end=11813,
)


_STREAMGETMAXTANGENTIALACCELERATIONREQUEST = _descriptor.Descriptor(
  name='StreamGetMaxTangentialAccelerationRequest',
  full_name='zaber.motion.protobufs.StreamGetMaxTangentialAccelerationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamGetMaxTangentialAccelerationRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamGetMaxTangentialAccelerationRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamGetMaxTangentialAccelerationRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.StreamGetMaxTangentialAccelerationRequest.unit', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11815,
  serialized_end=11929,
)


_STREAMGETMAXTANGENTIALACCELERATIONRESPONSE = _descriptor.Descriptor(
  name='StreamGetMaxTangentialAccelerationResponse',
  full_name='zaber.motion.protobufs.StreamGetMaxTangentialAccelerationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_tangential_acceleration', full_name='zaber.motion.protobufs.StreamGetMaxTangentialAccelerationResponse.max_tangential_acceleration', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=11931,
  serialized_end=12012,
)


_STREAMSETMAXTANGENTIALACCELERATIONREQUEST = _descriptor.Descriptor(
  name='StreamSetMaxTangentialAccelerationRequest',
  full_name='zaber.motion.protobufs.StreamSetMaxTangentialAccelerationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamSetMaxTangentialAccelerationRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamSetMaxTangentialAccelerationRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamSetMaxTangentialAccelerationRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_tangential_acceleration', full_name='zaber.motion.protobufs.StreamSetMaxTangentialAccelerationRequest.max_tangential_acceleration', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.StreamSetMaxTangentialAccelerationRequest.unit', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12015,
  serialized_end=12166,
)


_STREAMGETMAXCENTRIPETALACCELERATIONREQUEST = _descriptor.Descriptor(
  name='StreamGetMaxCentripetalAccelerationRequest',
  full_name='zaber.motion.protobufs.StreamGetMaxCentripetalAccelerationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamGetMaxCentripetalAccelerationRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamGetMaxCentripetalAccelerationRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamGetMaxCentripetalAccelerationRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.StreamGetMaxCentripetalAccelerationRequest.unit', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12168,
  serialized_end=12283,
)


_STREAMGETMAXCENTRIPETALACCELERATIONRESPONSE = _descriptor.Descriptor(
  name='StreamGetMaxCentripetalAccelerationResponse',
  full_name='zaber.motion.protobufs.StreamGetMaxCentripetalAccelerationResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='max_centripetal_acceleration', full_name='zaber.motion.protobufs.StreamGetMaxCentripetalAccelerationResponse.max_centripetal_acceleration', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12285,
  serialized_end=12368,
)


_STREAMSETMAXCENTRIPETALACCELERATIONREQUEST = _descriptor.Descriptor(
  name='StreamSetMaxCentripetalAccelerationRequest',
  full_name='zaber.motion.protobufs.StreamSetMaxCentripetalAccelerationRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamSetMaxCentripetalAccelerationRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamSetMaxCentripetalAccelerationRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamSetMaxCentripetalAccelerationRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='max_centripetal_acceleration', full_name='zaber.motion.protobufs.StreamSetMaxCentripetalAccelerationRequest.max_centripetal_acceleration', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.StreamSetMaxCentripetalAccelerationRequest.unit', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12371,
  serialized_end=12524,
)


_STREAMTOSTRINGREQUEST = _descriptor.Descriptor(
  name='StreamToStringRequest',
  full_name='zaber.motion.protobufs.StreamToStringRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamToStringRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamToStringRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamToStringRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12526,
  serialized_end=12606,
)


_STREAMTOSTRINGRESPONSE = _descriptor.Descriptor(
  name='StreamToStringResponse',
  full_name='zaber.motion.protobufs.StreamToStringResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='to_str', full_name='zaber.motion.protobufs.StreamToStringResponse.to_str', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12608,
  serialized_end=12648,
)


_STREAMDISABLEREQUEST = _descriptor.Descriptor(
  name='StreamDisableRequest',
  full_name='zaber.motion.protobufs.StreamDisableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamDisableRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamDisableRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stream_id', full_name='zaber.motion.protobufs.StreamDisableRequest.stream_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12650,
  serialized_end=12729,
)


_STREAMBUFFERGETCONTENTREQUEST = _descriptor.Descriptor(
  name='StreamBufferGetContentRequest',
  full_name='zaber.motion.protobufs.StreamBufferGetContentRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamBufferGetContentRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamBufferGetContentRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer_id', full_name='zaber.motion.protobufs.StreamBufferGetContentRequest.buffer_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12731,
  serialized_end=12819,
)


_STREAMBUFFERGETCONTENTRESPONSE = _descriptor.Descriptor(
  name='StreamBufferGetContentResponse',
  full_name='zaber.motion.protobufs.StreamBufferGetContentResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='buffer_lines', full_name='zaber.motion.protobufs.StreamBufferGetContentResponse.buffer_lines', index=0,
      number=1, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12821,
  serialized_end=12875,
)


_STREAMBUFFERERASEREQUEST = _descriptor.Descriptor(
  name='StreamBufferEraseRequest',
  full_name='zaber.motion.protobufs.StreamBufferEraseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.StreamBufferEraseRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.StreamBufferEraseRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='buffer_id', full_name='zaber.motion.protobufs.StreamBufferEraseRequest.buffer_id', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12877,
  serialized_end=12960,
)


_BINARYREPLYONLYEVENT = _descriptor.Descriptor(
  name='BinaryReplyOnlyEvent',
  full_name='zaber.motion.protobufs.BinaryReplyOnlyEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryReplyOnlyEvent.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_address', full_name='zaber.motion.protobufs.BinaryReplyOnlyEvent.device_address', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='zaber.motion.protobufs.BinaryReplyOnlyEvent.command', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.BinaryReplyOnlyEvent.data', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=12962,
  serialized_end=13061,
)


_OPENBINARYINTERFACEREQUEST = _descriptor.Descriptor(
  name='OpenBinaryInterfaceRequest',
  full_name='zaber.motion.protobufs.OpenBinaryInterfaceRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_type', full_name='zaber.motion.protobufs.OpenBinaryInterfaceRequest.interface_type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port_name', full_name='zaber.motion.protobufs.OpenBinaryInterfaceRequest.port_name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='baud_rate', full_name='zaber.motion.protobufs.OpenBinaryInterfaceRequest.baud_rate', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='host_name', full_name='zaber.motion.protobufs.OpenBinaryInterfaceRequest.host_name', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='port', full_name='zaber.motion.protobufs.OpenBinaryInterfaceRequest.port', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='use_message_ids', full_name='zaber.motion.protobufs.OpenBinaryInterfaceRequest.use_message_ids', index=5,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13064,
  serialized_end=13251,
)


_UNKNOWNBINARYRESPONSEEVENT = _descriptor.Descriptor(
  name='UnknownBinaryResponseEvent',
  full_name='zaber.motion.protobufs.UnknownBinaryResponseEvent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.UnknownBinaryResponseEvent.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_address', full_name='zaber.motion.protobufs.UnknownBinaryResponseEvent.device_address', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='zaber.motion.protobufs.UnknownBinaryResponseEvent.command', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.UnknownBinaryResponseEvent.data', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13253,
  serialized_end=13358,
)


_GENERICBINARYREQUEST = _descriptor.Descriptor(
  name='GenericBinaryRequest',
  full_name='zaber.motion.protobufs.GenericBinaryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.GenericBinaryRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.GenericBinaryRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='zaber.motion.protobufs.GenericBinaryRequest.command', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.GenericBinaryRequest.data', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='check_errors', full_name='zaber.motion.protobufs.GenericBinaryRequest.check_errors', index=4,
      number=5, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='zaber.motion.protobufs.GenericBinaryRequest.timeout', index=5,
      number=6, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13361,
  serialized_end=13491,
)


_BINARYMESSAGE = _descriptor.Descriptor(
  name='BinaryMessage',
  full_name='zaber.motion.protobufs.BinaryMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_address', full_name='zaber.motion.protobufs.BinaryMessage.device_address', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='zaber.motion.protobufs.BinaryMessage.command', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.BinaryMessage.data', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13493,
  serialized_end=13563,
)


_BINARYMESSAGECOLLECTION = _descriptor.Descriptor(
  name='BinaryMessageCollection',
  full_name='zaber.motion.protobufs.BinaryMessageCollection',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='messages', full_name='zaber.motion.protobufs.BinaryMessageCollection.messages', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13565,
  serialized_end=13647,
)


_BINARYDEVICERENUMBERREQUEST = _descriptor.Descriptor(
  name='BinaryDeviceRenumberRequest',
  full_name='zaber.motion.protobufs.BinaryDeviceRenumberRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryDeviceRenumberRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13649,
  serialized_end=13700,
)


_BINARYDEVICERENUMBERRESPONSE = _descriptor.Descriptor(
  name='BinaryDeviceRenumberResponse',
  full_name='zaber.motion.protobufs.BinaryDeviceRenumberResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='number_devices', full_name='zaber.motion.protobufs.BinaryDeviceRenumberResponse.number_devices', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13702,
  serialized_end=13756,
)


_BINARYDEVICEIDENTIFYREQUEST = _descriptor.Descriptor(
  name='BinaryDeviceIdentifyRequest',
  full_name='zaber.motion.protobufs.BinaryDeviceIdentifyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryDeviceIdentifyRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.BinaryDeviceIdentifyRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13758,
  serialized_end=13825,
)


_BINARYDEVICEIDENTITY = _descriptor.Descriptor(
  name='BinaryDeviceIdentity',
  full_name='zaber.motion.protobufs.BinaryDeviceIdentity',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='device_id', full_name='zaber.motion.protobufs.BinaryDeviceIdentity.device_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='serial_number', full_name='zaber.motion.protobufs.BinaryDeviceIdentity.serial_number', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='name', full_name='zaber.motion.protobufs.BinaryDeviceIdentity.name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='firmware_version', full_name='zaber.motion.protobufs.BinaryDeviceIdentity.firmware_version', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='is_peripheral', full_name='zaber.motion.protobufs.BinaryDeviceIdentity.is_peripheral', index=4,
      number=6, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peripheral_id', full_name='zaber.motion.protobufs.BinaryDeviceIdentity.peripheral_id', index=5,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='peripheral_name', full_name='zaber.motion.protobufs.BinaryDeviceIdentity.peripheral_name', index=6,
      number=8, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device_type', full_name='zaber.motion.protobufs.BinaryDeviceIdentity.device_type', index=7,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BINARYDEVICEIDENTITY_DEVICETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=13828,
  serialized_end=14173,
)


_BINARYDEVICEGETIDENTITYREQUEST = _descriptor.Descriptor(
  name='BinaryDeviceGetIdentityRequest',
  full_name='zaber.motion.protobufs.BinaryDeviceGetIdentityRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryDeviceGetIdentityRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.BinaryDeviceGetIdentityRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14175,
  serialized_end=14245,
)


_BINARYDEVICEGETIDENTITYRESPONSE = _descriptor.Descriptor(
  name='BinaryDeviceGetIdentityResponse',
  full_name='zaber.motion.protobufs.BinaryDeviceGetIdentityResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='identity', full_name='zaber.motion.protobufs.BinaryDeviceGetIdentityResponse.identity', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14247,
  serialized_end=14344,
)


_BINARYDEVICEGETISIDENTIFIEDREQUEST = _descriptor.Descriptor(
  name='BinaryDeviceGetIsIdentifiedRequest',
  full_name='zaber.motion.protobufs.BinaryDeviceGetIsIdentifiedRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryDeviceGetIsIdentifiedRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.BinaryDeviceGetIsIdentifiedRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14346,
  serialized_end=14420,
)


_BINARYDEVICEGETISIDENTIFIEDRESPONSE = _descriptor.Descriptor(
  name='BinaryDeviceGetIsIdentifiedResponse',
  full_name='zaber.motion.protobufs.BinaryDeviceGetIsIdentifiedResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_identified', full_name='zaber.motion.protobufs.BinaryDeviceGetIsIdentifiedResponse.is_identified', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14422,
  serialized_end=14482,
)


_BINARYGENERICWITHUNITSREQUEST = _descriptor.Descriptor(
  name='BinaryGenericWithUnitsRequest',
  full_name='zaber.motion.protobufs.BinaryGenericWithUnitsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryGenericWithUnitsRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.BinaryGenericWithUnitsRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='command', full_name='zaber.motion.protobufs.BinaryGenericWithUnitsRequest.command', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.BinaryGenericWithUnitsRequest.data', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='from_unit', full_name='zaber.motion.protobufs.BinaryGenericWithUnitsRequest.from_unit', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='to_unit', full_name='zaber.motion.protobufs.BinaryGenericWithUnitsRequest.to_unit', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='zaber.motion.protobufs.BinaryGenericWithUnitsRequest.timeout', index=6,
      number=7, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14485,
  serialized_end=14638,
)


_BINARYGENERICWITHUNITSRESPONSE = _descriptor.Descriptor(
  name='BinaryGenericWithUnitsResponse',
  full_name='zaber.motion.protobufs.BinaryGenericWithUnitsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.BinaryGenericWithUnitsResponse.data', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14640,
  serialized_end=14686,
)


_BINARYDEVICEHOMEREQUEST = _descriptor.Descriptor(
  name='BinaryDeviceHomeRequest',
  full_name='zaber.motion.protobufs.BinaryDeviceHomeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryDeviceHomeRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.BinaryDeviceHomeRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='zaber.motion.protobufs.BinaryDeviceHomeRequest.timeout', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.BinaryDeviceHomeRequest.unit', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14688,
  serialized_end=14782,
)


_BINARYDEVICEMOVEMENTRESPONSE = _descriptor.Descriptor(
  name='BinaryDeviceMovementResponse',
  full_name='zaber.motion.protobufs.BinaryDeviceMovementResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='data', full_name='zaber.motion.protobufs.BinaryDeviceMovementResponse.data', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14784,
  serialized_end=14828,
)


_BINARYDEVICEMOVEREQUEST = _descriptor.Descriptor(
  name='BinaryDeviceMoveRequest',
  full_name='zaber.motion.protobufs.BinaryDeviceMoveRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryDeviceMoveRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.BinaryDeviceMoveRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='zaber.motion.protobufs.BinaryDeviceMoveRequest.timeout', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='type', full_name='zaber.motion.protobufs.BinaryDeviceMoveRequest.type', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arg', full_name='zaber.motion.protobufs.BinaryDeviceMoveRequest.arg', index=4,
      number=5, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.BinaryDeviceMoveRequest.unit', index=5,
      number=6, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BINARYDEVICEMOVEREQUEST_MOVETYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=14831,
  serialized_end=15049,
)


_BINARYDEVICESTOPREQUEST = _descriptor.Descriptor(
  name='BinaryDeviceStopRequest',
  full_name='zaber.motion.protobufs.BinaryDeviceStopRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryDeviceStopRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.BinaryDeviceStopRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='timeout', full_name='zaber.motion.protobufs.BinaryDeviceStopRequest.timeout', index=2,
      number=3, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.BinaryDeviceStopRequest.unit', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15051,
  serialized_end=15145,
)


_BINARYDEVICEWAITUNTILIDLEREQUEST = _descriptor.Descriptor(
  name='BinaryDeviceWaitUntilIdleRequest',
  full_name='zaber.motion.protobufs.BinaryDeviceWaitUntilIdleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryDeviceWaitUntilIdleRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.BinaryDeviceWaitUntilIdleRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15147,
  serialized_end=15219,
)


_BINARYDEVICEISBUSYREQUEST = _descriptor.Descriptor(
  name='BinaryDeviceIsBusyRequest',
  full_name='zaber.motion.protobufs.BinaryDeviceIsBusyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryDeviceIsBusyRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.BinaryDeviceIsBusyRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15221,
  serialized_end=15286,
)


_BINARYDEVICEISBUSYRESPONSE = _descriptor.Descriptor(
  name='BinaryDeviceIsBusyResponse',
  full_name='zaber.motion.protobufs.BinaryDeviceIsBusyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_busy', full_name='zaber.motion.protobufs.BinaryDeviceIsBusyResponse.is_busy', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15288,
  serialized_end=15333,
)


_BINARYDEVICEDETECTREQUEST = _descriptor.Descriptor(
  name='BinaryDeviceDetectRequest',
  full_name='zaber.motion.protobufs.BinaryDeviceDetectRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryDeviceDetectRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='identify_devices', full_name='zaber.motion.protobufs.BinaryDeviceDetectRequest.identify_devices', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15335,
  serialized_end=15410,
)


_BINARYDEVICEDETECTRESPONSE = _descriptor.Descriptor(
  name='BinaryDeviceDetectResponse',
  full_name='zaber.motion.protobufs.BinaryDeviceDetectResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='devices', full_name='zaber.motion.protobufs.BinaryDeviceDetectResponse.devices', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15412,
  serialized_end=15457,
)


_BINARYDEVICEGETSETTINGREQUEST = _descriptor.Descriptor(
  name='BinaryDeviceGetSettingRequest',
  full_name='zaber.motion.protobufs.BinaryDeviceGetSettingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryDeviceGetSettingRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.BinaryDeviceGetSettingRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setting', full_name='zaber.motion.protobufs.BinaryDeviceGetSettingRequest.setting', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.BinaryDeviceGetSettingRequest.unit', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15459,
  serialized_end=15559,
)


_BINARYDEVICEGETSETTINGRESPONSE = _descriptor.Descriptor(
  name='BinaryDeviceGetSettingResponse',
  full_name='zaber.motion.protobufs.BinaryDeviceGetSettingResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.BinaryDeviceGetSettingResponse.value', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15561,
  serialized_end=15608,
)


_BINARYDEVICESETSETTINGREQUEST = _descriptor.Descriptor(
  name='BinaryDeviceSetSettingRequest',
  full_name='zaber.motion.protobufs.BinaryDeviceSetSettingRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryDeviceSetSettingRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.BinaryDeviceSetSettingRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='setting', full_name='zaber.motion.protobufs.BinaryDeviceSetSettingRequest.setting', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='zaber.motion.protobufs.BinaryDeviceSetSettingRequest.value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='unit', full_name='zaber.motion.protobufs.BinaryDeviceSetSettingRequest.unit', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15610,
  serialized_end=15725,
)


_BINARYDEVICEPARKREQUEST = _descriptor.Descriptor(
  name='BinaryDeviceParkRequest',
  full_name='zaber.motion.protobufs.BinaryDeviceParkRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='interface_id', full_name='zaber.motion.protobufs.BinaryDeviceParkRequest.interface_id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='device', full_name='zaber.motion.protobufs.BinaryDeviceParkRequest.device', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15727,
  serialized_end=15790,
)


_BINARYDEVICEPARKRESPONSE = _descriptor.Descriptor(
  name='BinaryDeviceParkResponse',
  full_name='zaber.motion.protobufs.BinaryDeviceParkResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='is_parked', full_name='zaber.motion.protobufs.BinaryDeviceParkResponse.is_parked', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=15792,
  serialized_end=15837,
)

_RESPONSE.fields_by_name['response'].enum_type = _RESPONSE_RESPONSETYPE
_RESPONSE.fields_by_name['error_type'].enum_type = _ERRORS
_RESPONSE_RESPONSETYPE.containing_type = _RESPONSE
_AXISIDENTITY.fields_by_name['axis_type'].enum_type = _AXISIDENTITY_AXISTYPE
_AXISIDENTITY_AXISTYPE.containing_type = _AXISIDENTITY
_DEVICEIDENTITY.fields_by_name['firmware_version'].message_type = _FIRMWAREVERSION
_OPENINTERFACEREQUEST.fields_by_name['interface_type'].enum_type = _INTERFACETYPE
_GENERICCOMMANDRESPONSE.fields_by_name['message_type'].enum_type = _MESSAGETYPE
_GENERICCOMMANDRESPONSECOLLECTION.fields_by_name['responses'].message_type = _GENERICCOMMANDRESPONSE
_UNKNOWNRESPONSEEVENT.fields_by_name['message_type'].enum_type = _MESSAGETYPE
_DISCONNECTEDEVENT.fields_by_name['error_type'].enum_type = _ERRORS
_DEVICEMOVEREQUEST.fields_by_name['type'].enum_type = _DEVICEMOVEREQUEST_MOVETYPE
_DEVICEMOVEREQUEST_MOVETYPE.containing_type = _DEVICEMOVEREQUEST
_DEVICEGETIDENTITYRESPONSE.fields_by_name['identity'].message_type = _DEVICEIDENTITY
_DEVICEGETAXISIDENTITYRESPONSE.fields_by_name['identity'].message_type = _AXISIDENTITY
_PREPARECOMMANDREQUEST.fields_by_name['parameters'].message_type = _MEASUREMENT
_LOCKSTEPMOVEREQUEST.fields_by_name['type'].enum_type = _LOCKSTEPMOVEREQUEST_MOVETYPE
_LOCKSTEPMOVEREQUEST_MOVETYPE.containing_type = _LOCKSTEPMOVEREQUEST
_LOCKSTEPGETAXESRESPONSE.fields_by_name['axes'].message_type = _LOCKSTEPAXES
_STREAMSETUPLIVECOMPOSITEREQUEST.fields_by_name['axes'].message_type = _STREAMAXISDEFINITION
_STREAMSETUPSTORECOMPOSITEREQUEST.fields_by_name['axes'].message_type = _STREAMAXISDEFINITION
_STREAMLINEREQUEST.fields_by_name['type'].enum_type = _STREAMLINEREQUEST_TYPE
_STREAMLINEREQUEST.fields_by_name['endpoint'].message_type = _MEASUREMENT
_STREAMLINEREQUEST_TYPE.containing_type = _STREAMLINEREQUEST
_STREAMARCREQUEST.fields_by_name['type'].enum_type = _STREAMARCREQUEST_TYPE
_STREAMARCREQUEST.fields_by_name['center_x'].message_type = _MEASUREMENT
_STREAMARCREQUEST.fields_by_name['center_y'].message_type = _MEASUREMENT
_STREAMARCREQUEST.fields_by_name['end_x'].message_type = _MEASUREMENT
_STREAMARCREQUEST.fields_by_name['end_y'].message_type = _MEASUREMENT
_STREAMARCREQUEST_TYPE.containing_type = _STREAMARCREQUEST
_STREAMCIRCLEREQUEST.fields_by_name['type'].enum_type = _STREAMCIRCLEREQUEST_TYPE
_STREAMCIRCLEREQUEST.fields_by_name['center_x'].message_type = _MEASUREMENT
_STREAMCIRCLEREQUEST.fields_by_name['center_y'].message_type = _MEASUREMENT
_STREAMCIRCLEREQUEST_TYPE.containing_type = _STREAMCIRCLEREQUEST
_STREAMGETAXESRESPONSE.fields_by_name['axes'].message_type = _STREAMAXISDEFINITION
_OPENBINARYINTERFACEREQUEST.fields_by_name['interface_type'].enum_type = _INTERFACETYPE
_BINARYMESSAGECOLLECTION.fields_by_name['messages'].message_type = _BINARYMESSAGE
_BINARYDEVICEIDENTITY.fields_by_name['firmware_version'].message_type = _FIRMWAREVERSION
_BINARYDEVICEIDENTITY.fields_by_name['device_type'].enum_type = _BINARYDEVICEIDENTITY_DEVICETYPE
_BINARYDEVICEIDENTITY_DEVICETYPE.containing_type = _BINARYDEVICEIDENTITY
_BINARYDEVICEGETIDENTITYRESPONSE.fields_by_name['identity'].message_type = _BINARYDEVICEIDENTITY
_BINARYDEVICEMOVEREQUEST.fields_by_name['type'].enum_type = _BINARYDEVICEMOVEREQUEST_MOVETYPE
_BINARYDEVICEMOVEREQUEST_MOVETYPE.containing_type = _BINARYDEVICEMOVEREQUEST
DESCRIPTOR.message_types_by_name['Request'] = _REQUEST
DESCRIPTOR.message_types_by_name['Response'] = _RESPONSE
DESCRIPTOR.message_types_by_name['Event'] = _EVENT
DESCRIPTOR.message_types_by_name['EmptyRequest'] = _EMPTYREQUEST
DESCRIPTOR.message_types_by_name['AxisIdentity'] = _AXISIDENTITY
DESCRIPTOR.message_types_by_name['DeviceIdentity'] = _DEVICEIDENTITY
DESCRIPTOR.message_types_by_name['FirmwareVersion'] = _FIRMWAREVERSION
DESCRIPTOR.message_types_by_name['DeviceIOInfo'] = _DEVICEIOINFO
DESCRIPTOR.message_types_by_name['Measurement'] = _MEASUREMENT
DESCRIPTOR.message_types_by_name['StreamAxisDefinition'] = _STREAMAXISDEFINITION
DESCRIPTOR.message_types_by_name['TestRequest'] = _TESTREQUEST
DESCRIPTOR.message_types_by_name['TestResponse'] = _TESTRESPONSE
DESCRIPTOR.message_types_by_name['TestResponseLong'] = _TESTRESPONSELONG
DESCRIPTOR.message_types_by_name['TestEvent'] = _TESTEVENT
DESCRIPTOR.message_types_by_name['ToolsListSerialPortsResponse'] = _TOOLSLISTSERIALPORTSRESPONSE
DESCRIPTOR.message_types_by_name['SetDeviceDbSourceRequest'] = _SETDEVICEDBSOURCEREQUEST
DESCRIPTOR.message_types_by_name['ToggleDeviceDbStoreRequest'] = _TOGGLEDEVICEDBSTOREREQUEST
DESCRIPTOR.message_types_by_name['OpenInterfaceRequest'] = _OPENINTERFACEREQUEST
DESCRIPTOR.message_types_by_name['OpenInterfaceResponse'] = _OPENINTERFACERESPONSE
DESCRIPTOR.message_types_by_name['CloseInterfaceRequest'] = _CLOSEINTERFACEREQUEST
DESCRIPTOR.message_types_by_name['EmptyInterfaceRequest'] = _EMPTYINTERFACEREQUEST
DESCRIPTOR.message_types_by_name['GetInterfaceTimeoutResponse'] = _GETINTERFACETIMEOUTRESPONSE
DESCRIPTOR.message_types_by_name['SetInterfaceTimeoutRequest'] = _SETINTERFACETIMEOUTREQUEST
DESCRIPTOR.message_types_by_name['GetInterfaceChecksumEnabledResponse'] = _GETINTERFACECHECKSUMENABLEDRESPONSE
DESCRIPTOR.message_types_by_name['SetInterfaceChecksumEnabledRequest'] = _SETINTERFACECHECKSUMENABLEDREQUEST
DESCRIPTOR.message_types_by_name['ToStringRequest'] = _TOSTRINGREQUEST
DESCRIPTOR.message_types_by_name['ToStringResponse'] = _TOSTRINGRESPONSE
DESCRIPTOR.message_types_by_name['GenericCommandRequest'] = _GENERICCOMMANDREQUEST
DESCRIPTOR.message_types_by_name['GenericCommandResponse'] = _GENERICCOMMANDRESPONSE
DESCRIPTOR.message_types_by_name['GenericCommandResponseCollection'] = _GENERICCOMMANDRESPONSECOLLECTION
DESCRIPTOR.message_types_by_name['UnknownResponseEvent'] = _UNKNOWNRESPONSEEVENT
DESCRIPTOR.message_types_by_name['AlertEvent'] = _ALERTEVENT
DESCRIPTOR.message_types_by_name['DisconnectedEvent'] = _DISCONNECTEDEVENT
DESCRIPTOR.message_types_by_name['DeviceRenumberRequest'] = _DEVICERENUMBERREQUEST
DESCRIPTOR.message_types_by_name['DeviceRenumberResponse'] = _DEVICERENUMBERRESPONSE
DESCRIPTOR.message_types_by_name['DeviceDetectRequest'] = _DEVICEDETECTREQUEST
DESCRIPTOR.message_types_by_name['DeviceDetectResponse'] = _DEVICEDETECTRESPONSE
DESCRIPTOR.message_types_by_name['DeviceHomeRequest'] = _DEVICEHOMEREQUEST
DESCRIPTOR.message_types_by_name['DeviceWaitUntilIdleRequest'] = _DEVICEWAITUNTILIDLEREQUEST
DESCRIPTOR.message_types_by_name['DeviceMoveRequest'] = _DEVICEMOVEREQUEST
DESCRIPTOR.message_types_by_name['DeviceStopRequest'] = _DEVICESTOPREQUEST
DESCRIPTOR.message_types_by_name['DeviceIdentifyRequest'] = _DEVICEIDENTIFYREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetIdentityRequest'] = _DEVICEGETIDENTITYREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetIdentityResponse'] = _DEVICEGETIDENTITYRESPONSE
DESCRIPTOR.message_types_by_name['DeviceGetIsIdentifiedRequest'] = _DEVICEGETISIDENTIFIEDREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetIsIdentifiedResponse'] = _DEVICEGETISIDENTIFIEDRESPONSE
DESCRIPTOR.message_types_by_name['DeviceGetAxisIdentityRequest'] = _DEVICEGETAXISIDENTITYREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetAxisIdentityResponse'] = _DEVICEGETAXISIDENTITYRESPONSE
DESCRIPTOR.message_types_by_name['DeviceIsBusyRequest'] = _DEVICEISBUSYREQUEST
DESCRIPTOR.message_types_by_name['DeviceIsBusyResponse'] = _DEVICEISBUSYRESPONSE
DESCRIPTOR.message_types_by_name['DeviceGetWarningsRequest'] = _DEVICEGETWARNINGSREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetWarningsResponse'] = _DEVICEGETWARNINGSRESPONSE
DESCRIPTOR.message_types_by_name['DeviceGetAllDigitalIORequest'] = _DEVICEGETALLDIGITALIOREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetAllDigitalIOResponse'] = _DEVICEGETALLDIGITALIORESPONSE
DESCRIPTOR.message_types_by_name['DeviceGetAllAnalogIORequest'] = _DEVICEGETALLANALOGIOREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetAllAnalogIOResponse'] = _DEVICEGETALLANALOGIORESPONSE
DESCRIPTOR.message_types_by_name['DeviceGetDigitalIORequest'] = _DEVICEGETDIGITALIOREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetDigitalIOResponse'] = _DEVICEGETDIGITALIORESPONSE
DESCRIPTOR.message_types_by_name['DeviceGetAnalogIORequest'] = _DEVICEGETANALOGIOREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetAnalogIOResponse'] = _DEVICEGETANALOGIORESPONSE
DESCRIPTOR.message_types_by_name['DeviceSetAllDigitalOutputsRequest'] = _DEVICESETALLDIGITALOUTPUTSREQUEST
DESCRIPTOR.message_types_by_name['DeviceSetAllAnalogOutputsRequest'] = _DEVICESETALLANALOGOUTPUTSREQUEST
DESCRIPTOR.message_types_by_name['DeviceSetDigitalOutputRequest'] = _DEVICESETDIGITALOUTPUTREQUEST
DESCRIPTOR.message_types_by_name['DeviceSetAnalogOutputRequest'] = _DEVICESETANALOGOUTPUTREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetIOChannelsInfoRequest'] = _DEVICEGETIOCHANNELSINFOREQUEST
DESCRIPTOR.message_types_by_name['SetLogOutputRequest'] = _SETLOGOUTPUTREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetSettingRequest'] = _DEVICEGETSETTINGREQUEST
DESCRIPTOR.message_types_by_name['DeviceGetSettingResponse'] = _DEVICEGETSETTINGRESPONSE
DESCRIPTOR.message_types_by_name['DeviceConvertSettingRequest'] = _DEVICECONVERTSETTINGREQUEST
DESCRIPTOR.message_types_by_name['DeviceConvertSettingResponse'] = _DEVICECONVERTSETTINGRESPONSE
DESCRIPTOR.message_types_by_name['DeviceSetSettingRequest'] = _DEVICESETSETTINGREQUEST
DESCRIPTOR.message_types_by_name['PrepareCommandRequest'] = _PREPARECOMMANDREQUEST
DESCRIPTOR.message_types_by_name['PrepareCommandResponse'] = _PREPARECOMMANDRESPONSE
DESCRIPTOR.message_types_by_name['DeviceParkRequest'] = _DEVICEPARKREQUEST
DESCRIPTOR.message_types_by_name['DeviceIsParkedResponse'] = _DEVICEISPARKEDRESPONSE
DESCRIPTOR.message_types_by_name['LockstepEnableRequest'] = _LOCKSTEPENABLEREQUEST
DESCRIPTOR.message_types_by_name['LockstepDisableRequest'] = _LOCKSTEPDISABLEREQUEST
DESCRIPTOR.message_types_by_name['LockstepStopRequest'] = _LOCKSTEPSTOPREQUEST
DESCRIPTOR.message_types_by_name['LockstepHomeRequest'] = _LOCKSTEPHOMEREQUEST
DESCRIPTOR.message_types_by_name['LockstepMoveRequest'] = _LOCKSTEPMOVEREQUEST
DESCRIPTOR.message_types_by_name['LockstepWaitUntilIdleRequest'] = _LOCKSTEPWAITUNTILIDLEREQUEST
DESCRIPTOR.message_types_by_name['LockstepIsBusyRequest'] = _LOCKSTEPISBUSYREQUEST
DESCRIPTOR.message_types_by_name['LockstepIsBusyResponse'] = _LOCKSTEPISBUSYRESPONSE
DESCRIPTOR.message_types_by_name['LockstepGetAxesRequest'] = _LOCKSTEPGETAXESREQUEST
DESCRIPTOR.message_types_by_name['LockstepAxes'] = _LOCKSTEPAXES
DESCRIPTOR.message_types_by_name['LockstepGetAxesResponse'] = _LOCKSTEPGETAXESRESPONSE
DESCRIPTOR.message_types_by_name['LockstepGetTwistRequest'] = _LOCKSTEPGETTWISTREQUEST
DESCRIPTOR.message_types_by_name['LockstepGetTwistResponse'] = _LOCKSTEPGETTWISTRESPONSE
DESCRIPTOR.message_types_by_name['LockstepGetTwistsResponse'] = _LOCKSTEPGETTWISTSRESPONSE
DESCRIPTOR.message_types_by_name['LockstepGetOffsetRequest'] = _LOCKSTEPGETOFFSETREQUEST
DESCRIPTOR.message_types_by_name['LockstepGetOffsetResponse'] = _LOCKSTEPGETOFFSETRESPONSE
DESCRIPTOR.message_types_by_name['LockstepGetOffsetsResponse'] = _LOCKSTEPGETOFFSETSRESPONSE
DESCRIPTOR.message_types_by_name['LockstepIsEnabledRequest'] = _LOCKSTEPISENABLEDREQUEST
DESCRIPTOR.message_types_by_name['LockstepIsEnabledResponse'] = _LOCKSTEPISENABLEDRESPONSE
DESCRIPTOR.message_types_by_name['LockstepToStringRequest'] = _LOCKSTEPTOSTRINGREQUEST
DESCRIPTOR.message_types_by_name['LockstepToStringResponse'] = _LOCKSTEPTOSTRINGRESPONSE
DESCRIPTOR.message_types_by_name['StreamSetupLiveRequest'] = _STREAMSETUPLIVEREQUEST
DESCRIPTOR.message_types_by_name['StreamSetupLiveCompositeRequest'] = _STREAMSETUPLIVECOMPOSITEREQUEST
DESCRIPTOR.message_types_by_name['StreamSetupStoreRequest'] = _STREAMSETUPSTOREREQUEST
DESCRIPTOR.message_types_by_name['StreamSetupStoreCompositeRequest'] = _STREAMSETUPSTORECOMPOSITEREQUEST
DESCRIPTOR.message_types_by_name['StreamSetupStoreArbitraryAxesRequest'] = _STREAMSETUPSTOREARBITRARYAXESREQUEST
DESCRIPTOR.message_types_by_name['StreamCallRequest'] = _STREAMCALLREQUEST
DESCRIPTOR.message_types_by_name['StreamLineRequest'] = _STREAMLINEREQUEST
DESCRIPTOR.message_types_by_name['StreamArcRequest'] = _STREAMARCREQUEST
DESCRIPTOR.message_types_by_name['StreamCircleRequest'] = _STREAMCIRCLEREQUEST
DESCRIPTOR.message_types_by_name['StreamWaitDigitalInputRequest'] = _STREAMWAITDIGITALINPUTREQUEST
DESCRIPTOR.message_types_by_name['StreamWaitAnalogInputRequest'] = _STREAMWAITANALOGINPUTREQUEST
DESCRIPTOR.message_types_by_name['StreamSetDigitalOutputRequest'] = _STREAMSETDIGITALOUTPUTREQUEST
DESCRIPTOR.message_types_by_name['StreamSetAnalogOutputRequest'] = _STREAMSETANALOGOUTPUTREQUEST
DESCRIPTOR.message_types_by_name['StreamToggleDigitalOutputRequest'] = _STREAMTOGGLEDIGITALOUTPUTREQUEST
DESCRIPTOR.message_types_by_name['StreamWaitRequest'] = _STREAMWAITREQUEST
DESCRIPTOR.message_types_by_name['StreamWaitUntilIdleRequest'] = _STREAMWAITUNTILIDLEREQUEST
DESCRIPTOR.message_types_by_name['StreamCorkRequest'] = _STREAMCORKREQUEST
DESCRIPTOR.message_types_by_name['StreamUncorkRequest'] = _STREAMUNCORKREQUEST
DESCRIPTOR.message_types_by_name['StreamIsBusyRequest'] = _STREAMISBUSYREQUEST
DESCRIPTOR.message_types_by_name['StreamIsBusyResponse'] = _STREAMISBUSYRESPONSE
DESCRIPTOR.message_types_by_name['StreamGetAxesRequest'] = _STREAMGETAXESREQUEST
DESCRIPTOR.message_types_by_name['StreamGetAxesResponse'] = _STREAMGETAXESRESPONSE
DESCRIPTOR.message_types_by_name['StreamGetModeRequest'] = _STREAMGETMODEREQUEST
DESCRIPTOR.message_types_by_name['StreamGetModeResponse'] = _STREAMGETMODERESPONSE
DESCRIPTOR.message_types_by_name['StreamGetMaxSpeedRequest'] = _STREAMGETMAXSPEEDREQUEST
DESCRIPTOR.message_types_by_name['StreamGetMaxSpeedResponse'] = _STREAMGETMAXSPEEDRESPONSE
DESCRIPTOR.message_types_by_name['StreamSetMaxSpeedRequest'] = _STREAMSETMAXSPEEDREQUEST
DESCRIPTOR.message_types_by_name['StreamGetMaxTangentialAccelerationRequest'] = _STREAMGETMAXTANGENTIALACCELERATIONREQUEST
DESCRIPTOR.message_types_by_name['StreamGetMaxTangentialAccelerationResponse'] = _STREAMGETMAXTANGENTIALACCELERATIONRESPONSE
DESCRIPTOR.message_types_by_name['StreamSetMaxTangentialAccelerationRequest'] = _STREAMSETMAXTANGENTIALACCELERATIONREQUEST
DESCRIPTOR.message_types_by_name['StreamGetMaxCentripetalAccelerationRequest'] = _STREAMGETMAXCENTRIPETALACCELERATIONREQUEST
DESCRIPTOR.message_types_by_name['StreamGetMaxCentripetalAccelerationResponse'] = _STREAMGETMAXCENTRIPETALACCELERATIONRESPONSE
DESCRIPTOR.message_types_by_name['StreamSetMaxCentripetalAccelerationRequest'] = _STREAMSETMAXCENTRIPETALACCELERATIONREQUEST
DESCRIPTOR.message_types_by_name['StreamToStringRequest'] = _STREAMTOSTRINGREQUEST
DESCRIPTOR.message_types_by_name['StreamToStringResponse'] = _STREAMTOSTRINGRESPONSE
DESCRIPTOR.message_types_by_name['StreamDisableRequest'] = _STREAMDISABLEREQUEST
DESCRIPTOR.message_types_by_name['StreamBufferGetContentRequest'] = _STREAMBUFFERGETCONTENTREQUEST
DESCRIPTOR.message_types_by_name['StreamBufferGetContentResponse'] = _STREAMBUFFERGETCONTENTRESPONSE
DESCRIPTOR.message_types_by_name['StreamBufferEraseRequest'] = _STREAMBUFFERERASEREQUEST
DESCRIPTOR.message_types_by_name['BinaryReplyOnlyEvent'] = _BINARYREPLYONLYEVENT
DESCRIPTOR.message_types_by_name['OpenBinaryInterfaceRequest'] = _OPENBINARYINTERFACEREQUEST
DESCRIPTOR.message_types_by_name['UnknownBinaryResponseEvent'] = _UNKNOWNBINARYRESPONSEEVENT
DESCRIPTOR.message_types_by_name['GenericBinaryRequest'] = _GENERICBINARYREQUEST
DESCRIPTOR.message_types_by_name['BinaryMessage'] = _BINARYMESSAGE
DESCRIPTOR.message_types_by_name['BinaryMessageCollection'] = _BINARYMESSAGECOLLECTION
DESCRIPTOR.message_types_by_name['BinaryDeviceRenumberRequest'] = _BINARYDEVICERENUMBERREQUEST
DESCRIPTOR.message_types_by_name['BinaryDeviceRenumberResponse'] = _BINARYDEVICERENUMBERRESPONSE
DESCRIPTOR.message_types_by_name['BinaryDeviceIdentifyRequest'] = _BINARYDEVICEIDENTIFYREQUEST
DESCRIPTOR.message_types_by_name['BinaryDeviceIdentity'] = _BINARYDEVICEIDENTITY
DESCRIPTOR.message_types_by_name['BinaryDeviceGetIdentityRequest'] = _BINARYDEVICEGETIDENTITYREQUEST
DESCRIPTOR.message_types_by_name['BinaryDeviceGetIdentityResponse'] = _BINARYDEVICEGETIDENTITYRESPONSE
DESCRIPTOR.message_types_by_name['BinaryDeviceGetIsIdentifiedRequest'] = _BINARYDEVICEGETISIDENTIFIEDREQUEST
DESCRIPTOR.message_types_by_name['BinaryDeviceGetIsIdentifiedResponse'] = _BINARYDEVICEGETISIDENTIFIEDRESPONSE
DESCRIPTOR.message_types_by_name['BinaryGenericWithUnitsRequest'] = _BINARYGENERICWITHUNITSREQUEST
DESCRIPTOR.message_types_by_name['BinaryGenericWithUnitsResponse'] = _BINARYGENERICWITHUNITSRESPONSE
DESCRIPTOR.message_types_by_name['BinaryDeviceHomeRequest'] = _BINARYDEVICEHOMEREQUEST
DESCRIPTOR.message_types_by_name['BinaryDeviceMovementResponse'] = _BINARYDEVICEMOVEMENTRESPONSE
DESCRIPTOR.message_types_by_name['BinaryDeviceMoveRequest'] = _BINARYDEVICEMOVEREQUEST
DESCRIPTOR.message_types_by_name['BinaryDeviceStopRequest'] = _BINARYDEVICESTOPREQUEST
DESCRIPTOR.message_types_by_name['BinaryDeviceWaitUntilIdleRequest'] = _BINARYDEVICEWAITUNTILIDLEREQUEST
DESCRIPTOR.message_types_by_name['BinaryDeviceIsBusyRequest'] = _BINARYDEVICEISBUSYREQUEST
DESCRIPTOR.message_types_by_name['BinaryDeviceIsBusyResponse'] = _BINARYDEVICEISBUSYRESPONSE
DESCRIPTOR.message_types_by_name['BinaryDeviceDetectRequest'] = _BINARYDEVICEDETECTREQUEST
DESCRIPTOR.message_types_by_name['BinaryDeviceDetectResponse'] = _BINARYDEVICEDETECTRESPONSE
DESCRIPTOR.message_types_by_name['BinaryDeviceGetSettingRequest'] = _BINARYDEVICEGETSETTINGREQUEST
DESCRIPTOR.message_types_by_name['BinaryDeviceGetSettingResponse'] = _BINARYDEVICEGETSETTINGRESPONSE
DESCRIPTOR.message_types_by_name['BinaryDeviceSetSettingRequest'] = _BINARYDEVICESETSETTINGREQUEST
DESCRIPTOR.message_types_by_name['BinaryDeviceParkRequest'] = _BINARYDEVICEPARKREQUEST
DESCRIPTOR.message_types_by_name['BinaryDeviceParkResponse'] = _BINARYDEVICEPARKRESPONSE
DESCRIPTOR.enum_types_by_name['MessageType'] = _MESSAGETYPE
DESCRIPTOR.enum_types_by_name['Errors'] = _ERRORS
DESCRIPTOR.enum_types_by_name['InterfaceType'] = _INTERFACETYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Request = _reflection.GeneratedProtocolMessageType('Request', (_message.Message,), {
  'DESCRIPTOR' : _REQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.Request)
  })
_sym_db.RegisterMessage(Request)

Response = _reflection.GeneratedProtocolMessageType('Response', (_message.Message,), {
  'DESCRIPTOR' : _RESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.Response)
  })
_sym_db.RegisterMessage(Response)

Event = _reflection.GeneratedProtocolMessageType('Event', (_message.Message,), {
  'DESCRIPTOR' : _EVENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.Event)
  })
_sym_db.RegisterMessage(Event)

EmptyRequest = _reflection.GeneratedProtocolMessageType('EmptyRequest', (_message.Message,), {
  'DESCRIPTOR' : _EMPTYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.EmptyRequest)
  })
_sym_db.RegisterMessage(EmptyRequest)

AxisIdentity = _reflection.GeneratedProtocolMessageType('AxisIdentity', (_message.Message,), {
  'DESCRIPTOR' : _AXISIDENTITY,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.AxisIdentity)
  })
_sym_db.RegisterMessage(AxisIdentity)

DeviceIdentity = _reflection.GeneratedProtocolMessageType('DeviceIdentity', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIDENTITY,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIdentity)
  })
_sym_db.RegisterMessage(DeviceIdentity)

FirmwareVersion = _reflection.GeneratedProtocolMessageType('FirmwareVersion', (_message.Message,), {
  'DESCRIPTOR' : _FIRMWAREVERSION,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.FirmwareVersion)
  })
_sym_db.RegisterMessage(FirmwareVersion)

DeviceIOInfo = _reflection.GeneratedProtocolMessageType('DeviceIOInfo', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIOINFO,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIOInfo)
  })
_sym_db.RegisterMessage(DeviceIOInfo)

Measurement = _reflection.GeneratedProtocolMessageType('Measurement', (_message.Message,), {
  'DESCRIPTOR' : _MEASUREMENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.Measurement)
  })
_sym_db.RegisterMessage(Measurement)

StreamAxisDefinition = _reflection.GeneratedProtocolMessageType('StreamAxisDefinition', (_message.Message,), {
  'DESCRIPTOR' : _STREAMAXISDEFINITION,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamAxisDefinition)
  })
_sym_db.RegisterMessage(StreamAxisDefinition)

TestRequest = _reflection.GeneratedProtocolMessageType('TestRequest', (_message.Message,), {
  'DESCRIPTOR' : _TESTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TestRequest)
  })
_sym_db.RegisterMessage(TestRequest)

TestResponse = _reflection.GeneratedProtocolMessageType('TestResponse', (_message.Message,), {
  'DESCRIPTOR' : _TESTRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TestResponse)
  })
_sym_db.RegisterMessage(TestResponse)

TestResponseLong = _reflection.GeneratedProtocolMessageType('TestResponseLong', (_message.Message,), {
  'DESCRIPTOR' : _TESTRESPONSELONG,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TestResponseLong)
  })
_sym_db.RegisterMessage(TestResponseLong)

TestEvent = _reflection.GeneratedProtocolMessageType('TestEvent', (_message.Message,), {
  'DESCRIPTOR' : _TESTEVENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.TestEvent)
  })
_sym_db.RegisterMessage(TestEvent)

ToolsListSerialPortsResponse = _reflection.GeneratedProtocolMessageType('ToolsListSerialPortsResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOOLSLISTSERIALPORTSRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ToolsListSerialPortsResponse)
  })
_sym_db.RegisterMessage(ToolsListSerialPortsResponse)

SetDeviceDbSourceRequest = _reflection.GeneratedProtocolMessageType('SetDeviceDbSourceRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETDEVICEDBSOURCEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetDeviceDbSourceRequest)
  })
_sym_db.RegisterMessage(SetDeviceDbSourceRequest)

ToggleDeviceDbStoreRequest = _reflection.GeneratedProtocolMessageType('ToggleDeviceDbStoreRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOGGLEDEVICEDBSTOREREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ToggleDeviceDbStoreRequest)
  })
_sym_db.RegisterMessage(ToggleDeviceDbStoreRequest)

OpenInterfaceRequest = _reflection.GeneratedProtocolMessageType('OpenInterfaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _OPENINTERFACEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OpenInterfaceRequest)
  })
_sym_db.RegisterMessage(OpenInterfaceRequest)

OpenInterfaceResponse = _reflection.GeneratedProtocolMessageType('OpenInterfaceResponse', (_message.Message,), {
  'DESCRIPTOR' : _OPENINTERFACERESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OpenInterfaceResponse)
  })
_sym_db.RegisterMessage(OpenInterfaceResponse)

CloseInterfaceRequest = _reflection.GeneratedProtocolMessageType('CloseInterfaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOSEINTERFACEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.CloseInterfaceRequest)
  })
_sym_db.RegisterMessage(CloseInterfaceRequest)

EmptyInterfaceRequest = _reflection.GeneratedProtocolMessageType('EmptyInterfaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _EMPTYINTERFACEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.EmptyInterfaceRequest)
  })
_sym_db.RegisterMessage(EmptyInterfaceRequest)

GetInterfaceTimeoutResponse = _reflection.GeneratedProtocolMessageType('GetInterfaceTimeoutResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERFACETIMEOUTRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GetInterfaceTimeoutResponse)
  })
_sym_db.RegisterMessage(GetInterfaceTimeoutResponse)

SetInterfaceTimeoutRequest = _reflection.GeneratedProtocolMessageType('SetInterfaceTimeoutRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETINTERFACETIMEOUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetInterfaceTimeoutRequest)
  })
_sym_db.RegisterMessage(SetInterfaceTimeoutRequest)

GetInterfaceChecksumEnabledResponse = _reflection.GeneratedProtocolMessageType('GetInterfaceChecksumEnabledResponse', (_message.Message,), {
  'DESCRIPTOR' : _GETINTERFACECHECKSUMENABLEDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GetInterfaceChecksumEnabledResponse)
  })
_sym_db.RegisterMessage(GetInterfaceChecksumEnabledResponse)

SetInterfaceChecksumEnabledRequest = _reflection.GeneratedProtocolMessageType('SetInterfaceChecksumEnabledRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETINTERFACECHECKSUMENABLEDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetInterfaceChecksumEnabledRequest)
  })
_sym_db.RegisterMessage(SetInterfaceChecksumEnabledRequest)

ToStringRequest = _reflection.GeneratedProtocolMessageType('ToStringRequest', (_message.Message,), {
  'DESCRIPTOR' : _TOSTRINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ToStringRequest)
  })
_sym_db.RegisterMessage(ToStringRequest)

ToStringResponse = _reflection.GeneratedProtocolMessageType('ToStringResponse', (_message.Message,), {
  'DESCRIPTOR' : _TOSTRINGRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.ToStringResponse)
  })
_sym_db.RegisterMessage(ToStringResponse)

GenericCommandRequest = _reflection.GeneratedProtocolMessageType('GenericCommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERICCOMMANDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GenericCommandRequest)
  })
_sym_db.RegisterMessage(GenericCommandRequest)

GenericCommandResponse = _reflection.GeneratedProtocolMessageType('GenericCommandResponse', (_message.Message,), {
  'DESCRIPTOR' : _GENERICCOMMANDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GenericCommandResponse)
  })
_sym_db.RegisterMessage(GenericCommandResponse)

GenericCommandResponseCollection = _reflection.GeneratedProtocolMessageType('GenericCommandResponseCollection', (_message.Message,), {
  'DESCRIPTOR' : _GENERICCOMMANDRESPONSECOLLECTION,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GenericCommandResponseCollection)
  })
_sym_db.RegisterMessage(GenericCommandResponseCollection)

UnknownResponseEvent = _reflection.GeneratedProtocolMessageType('UnknownResponseEvent', (_message.Message,), {
  'DESCRIPTOR' : _UNKNOWNRESPONSEEVENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.UnknownResponseEvent)
  })
_sym_db.RegisterMessage(UnknownResponseEvent)

AlertEvent = _reflection.GeneratedProtocolMessageType('AlertEvent', (_message.Message,), {
  'DESCRIPTOR' : _ALERTEVENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.AlertEvent)
  })
_sym_db.RegisterMessage(AlertEvent)

DisconnectedEvent = _reflection.GeneratedProtocolMessageType('DisconnectedEvent', (_message.Message,), {
  'DESCRIPTOR' : _DISCONNECTEDEVENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DisconnectedEvent)
  })
_sym_db.RegisterMessage(DisconnectedEvent)

DeviceRenumberRequest = _reflection.GeneratedProtocolMessageType('DeviceRenumberRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICERENUMBERREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceRenumberRequest)
  })
_sym_db.RegisterMessage(DeviceRenumberRequest)

DeviceRenumberResponse = _reflection.GeneratedProtocolMessageType('DeviceRenumberResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICERENUMBERRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceRenumberResponse)
  })
_sym_db.RegisterMessage(DeviceRenumberResponse)

DeviceDetectRequest = _reflection.GeneratedProtocolMessageType('DeviceDetectRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEDETECTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceDetectRequest)
  })
_sym_db.RegisterMessage(DeviceDetectRequest)

DeviceDetectResponse = _reflection.GeneratedProtocolMessageType('DeviceDetectResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEDETECTRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceDetectResponse)
  })
_sym_db.RegisterMessage(DeviceDetectResponse)

DeviceHomeRequest = _reflection.GeneratedProtocolMessageType('DeviceHomeRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEHOMEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceHomeRequest)
  })
_sym_db.RegisterMessage(DeviceHomeRequest)

DeviceWaitUntilIdleRequest = _reflection.GeneratedProtocolMessageType('DeviceWaitUntilIdleRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEWAITUNTILIDLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceWaitUntilIdleRequest)
  })
_sym_db.RegisterMessage(DeviceWaitUntilIdleRequest)

DeviceMoveRequest = _reflection.GeneratedProtocolMessageType('DeviceMoveRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEMOVEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceMoveRequest)
  })
_sym_db.RegisterMessage(DeviceMoveRequest)

DeviceStopRequest = _reflection.GeneratedProtocolMessageType('DeviceStopRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESTOPREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceStopRequest)
  })
_sym_db.RegisterMessage(DeviceStopRequest)

DeviceIdentifyRequest = _reflection.GeneratedProtocolMessageType('DeviceIdentifyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEIDENTIFYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIdentifyRequest)
  })
_sym_db.RegisterMessage(DeviceIdentifyRequest)

DeviceGetIdentityRequest = _reflection.GeneratedProtocolMessageType('DeviceGetIdentityRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETIDENTITYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetIdentityRequest)
  })
_sym_db.RegisterMessage(DeviceGetIdentityRequest)

DeviceGetIdentityResponse = _reflection.GeneratedProtocolMessageType('DeviceGetIdentityResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETIDENTITYRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetIdentityResponse)
  })
_sym_db.RegisterMessage(DeviceGetIdentityResponse)

DeviceGetIsIdentifiedRequest = _reflection.GeneratedProtocolMessageType('DeviceGetIsIdentifiedRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETISIDENTIFIEDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetIsIdentifiedRequest)
  })
_sym_db.RegisterMessage(DeviceGetIsIdentifiedRequest)

DeviceGetIsIdentifiedResponse = _reflection.GeneratedProtocolMessageType('DeviceGetIsIdentifiedResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETISIDENTIFIEDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetIsIdentifiedResponse)
  })
_sym_db.RegisterMessage(DeviceGetIsIdentifiedResponse)

DeviceGetAxisIdentityRequest = _reflection.GeneratedProtocolMessageType('DeviceGetAxisIdentityRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETAXISIDENTITYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAxisIdentityRequest)
  })
_sym_db.RegisterMessage(DeviceGetAxisIdentityRequest)

DeviceGetAxisIdentityResponse = _reflection.GeneratedProtocolMessageType('DeviceGetAxisIdentityResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETAXISIDENTITYRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAxisIdentityResponse)
  })
_sym_db.RegisterMessage(DeviceGetAxisIdentityResponse)

DeviceIsBusyRequest = _reflection.GeneratedProtocolMessageType('DeviceIsBusyRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEISBUSYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIsBusyRequest)
  })
_sym_db.RegisterMessage(DeviceIsBusyRequest)

DeviceIsBusyResponse = _reflection.GeneratedProtocolMessageType('DeviceIsBusyResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEISBUSYRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIsBusyResponse)
  })
_sym_db.RegisterMessage(DeviceIsBusyResponse)

DeviceGetWarningsRequest = _reflection.GeneratedProtocolMessageType('DeviceGetWarningsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETWARNINGSREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetWarningsRequest)
  })
_sym_db.RegisterMessage(DeviceGetWarningsRequest)

DeviceGetWarningsResponse = _reflection.GeneratedProtocolMessageType('DeviceGetWarningsResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETWARNINGSRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetWarningsResponse)
  })
_sym_db.RegisterMessage(DeviceGetWarningsResponse)

DeviceGetAllDigitalIORequest = _reflection.GeneratedProtocolMessageType('DeviceGetAllDigitalIORequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETALLDIGITALIOREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAllDigitalIORequest)
  })
_sym_db.RegisterMessage(DeviceGetAllDigitalIORequest)

DeviceGetAllDigitalIOResponse = _reflection.GeneratedProtocolMessageType('DeviceGetAllDigitalIOResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETALLDIGITALIORESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAllDigitalIOResponse)
  })
_sym_db.RegisterMessage(DeviceGetAllDigitalIOResponse)

DeviceGetAllAnalogIORequest = _reflection.GeneratedProtocolMessageType('DeviceGetAllAnalogIORequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETALLANALOGIOREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAllAnalogIORequest)
  })
_sym_db.RegisterMessage(DeviceGetAllAnalogIORequest)

DeviceGetAllAnalogIOResponse = _reflection.GeneratedProtocolMessageType('DeviceGetAllAnalogIOResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETALLANALOGIORESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAllAnalogIOResponse)
  })
_sym_db.RegisterMessage(DeviceGetAllAnalogIOResponse)

DeviceGetDigitalIORequest = _reflection.GeneratedProtocolMessageType('DeviceGetDigitalIORequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETDIGITALIOREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetDigitalIORequest)
  })
_sym_db.RegisterMessage(DeviceGetDigitalIORequest)

DeviceGetDigitalIOResponse = _reflection.GeneratedProtocolMessageType('DeviceGetDigitalIOResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETDIGITALIORESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetDigitalIOResponse)
  })
_sym_db.RegisterMessage(DeviceGetDigitalIOResponse)

DeviceGetAnalogIORequest = _reflection.GeneratedProtocolMessageType('DeviceGetAnalogIORequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETANALOGIOREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAnalogIORequest)
  })
_sym_db.RegisterMessage(DeviceGetAnalogIORequest)

DeviceGetAnalogIOResponse = _reflection.GeneratedProtocolMessageType('DeviceGetAnalogIOResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETANALOGIORESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetAnalogIOResponse)
  })
_sym_db.RegisterMessage(DeviceGetAnalogIOResponse)

DeviceSetAllDigitalOutputsRequest = _reflection.GeneratedProtocolMessageType('DeviceSetAllDigitalOutputsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESETALLDIGITALOUTPUTSREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceSetAllDigitalOutputsRequest)
  })
_sym_db.RegisterMessage(DeviceSetAllDigitalOutputsRequest)

DeviceSetAllAnalogOutputsRequest = _reflection.GeneratedProtocolMessageType('DeviceSetAllAnalogOutputsRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESETALLANALOGOUTPUTSREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceSetAllAnalogOutputsRequest)
  })
_sym_db.RegisterMessage(DeviceSetAllAnalogOutputsRequest)

DeviceSetDigitalOutputRequest = _reflection.GeneratedProtocolMessageType('DeviceSetDigitalOutputRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESETDIGITALOUTPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceSetDigitalOutputRequest)
  })
_sym_db.RegisterMessage(DeviceSetDigitalOutputRequest)

DeviceSetAnalogOutputRequest = _reflection.GeneratedProtocolMessageType('DeviceSetAnalogOutputRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESETANALOGOUTPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceSetAnalogOutputRequest)
  })
_sym_db.RegisterMessage(DeviceSetAnalogOutputRequest)

DeviceGetIOChannelsInfoRequest = _reflection.GeneratedProtocolMessageType('DeviceGetIOChannelsInfoRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETIOCHANNELSINFOREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetIOChannelsInfoRequest)
  })
_sym_db.RegisterMessage(DeviceGetIOChannelsInfoRequest)

SetLogOutputRequest = _reflection.GeneratedProtocolMessageType('SetLogOutputRequest', (_message.Message,), {
  'DESCRIPTOR' : _SETLOGOUTPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.SetLogOutputRequest)
  })
_sym_db.RegisterMessage(SetLogOutputRequest)

DeviceGetSettingRequest = _reflection.GeneratedProtocolMessageType('DeviceGetSettingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETSETTINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetSettingRequest)
  })
_sym_db.RegisterMessage(DeviceGetSettingRequest)

DeviceGetSettingResponse = _reflection.GeneratedProtocolMessageType('DeviceGetSettingResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEGETSETTINGRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceGetSettingResponse)
  })
_sym_db.RegisterMessage(DeviceGetSettingResponse)

DeviceConvertSettingRequest = _reflection.GeneratedProtocolMessageType('DeviceConvertSettingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICECONVERTSETTINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceConvertSettingRequest)
  })
_sym_db.RegisterMessage(DeviceConvertSettingRequest)

DeviceConvertSettingResponse = _reflection.GeneratedProtocolMessageType('DeviceConvertSettingResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICECONVERTSETTINGRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceConvertSettingResponse)
  })
_sym_db.RegisterMessage(DeviceConvertSettingResponse)

DeviceSetSettingRequest = _reflection.GeneratedProtocolMessageType('DeviceSetSettingRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICESETSETTINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceSetSettingRequest)
  })
_sym_db.RegisterMessage(DeviceSetSettingRequest)

PrepareCommandRequest = _reflection.GeneratedProtocolMessageType('PrepareCommandRequest', (_message.Message,), {
  'DESCRIPTOR' : _PREPARECOMMANDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.PrepareCommandRequest)
  })
_sym_db.RegisterMessage(PrepareCommandRequest)

PrepareCommandResponse = _reflection.GeneratedProtocolMessageType('PrepareCommandResponse', (_message.Message,), {
  'DESCRIPTOR' : _PREPARECOMMANDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.PrepareCommandResponse)
  })
_sym_db.RegisterMessage(PrepareCommandResponse)

DeviceParkRequest = _reflection.GeneratedProtocolMessageType('DeviceParkRequest', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEPARKREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceParkRequest)
  })
_sym_db.RegisterMessage(DeviceParkRequest)

DeviceIsParkedResponse = _reflection.GeneratedProtocolMessageType('DeviceIsParkedResponse', (_message.Message,), {
  'DESCRIPTOR' : _DEVICEISPARKEDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.DeviceIsParkedResponse)
  })
_sym_db.RegisterMessage(DeviceIsParkedResponse)

LockstepEnableRequest = _reflection.GeneratedProtocolMessageType('LockstepEnableRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPENABLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepEnableRequest)
  })
_sym_db.RegisterMessage(LockstepEnableRequest)

LockstepDisableRequest = _reflection.GeneratedProtocolMessageType('LockstepDisableRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPDISABLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepDisableRequest)
  })
_sym_db.RegisterMessage(LockstepDisableRequest)

LockstepStopRequest = _reflection.GeneratedProtocolMessageType('LockstepStopRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPSTOPREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepStopRequest)
  })
_sym_db.RegisterMessage(LockstepStopRequest)

LockstepHomeRequest = _reflection.GeneratedProtocolMessageType('LockstepHomeRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPHOMEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepHomeRequest)
  })
_sym_db.RegisterMessage(LockstepHomeRequest)

LockstepMoveRequest = _reflection.GeneratedProtocolMessageType('LockstepMoveRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPMOVEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepMoveRequest)
  })
_sym_db.RegisterMessage(LockstepMoveRequest)

LockstepWaitUntilIdleRequest = _reflection.GeneratedProtocolMessageType('LockstepWaitUntilIdleRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPWAITUNTILIDLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepWaitUntilIdleRequest)
  })
_sym_db.RegisterMessage(LockstepWaitUntilIdleRequest)

LockstepIsBusyRequest = _reflection.GeneratedProtocolMessageType('LockstepIsBusyRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPISBUSYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepIsBusyRequest)
  })
_sym_db.RegisterMessage(LockstepIsBusyRequest)

LockstepIsBusyResponse = _reflection.GeneratedProtocolMessageType('LockstepIsBusyResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPISBUSYRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepIsBusyResponse)
  })
_sym_db.RegisterMessage(LockstepIsBusyResponse)

LockstepGetAxesRequest = _reflection.GeneratedProtocolMessageType('LockstepGetAxesRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETAXESREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetAxesRequest)
  })
_sym_db.RegisterMessage(LockstepGetAxesRequest)

LockstepAxes = _reflection.GeneratedProtocolMessageType('LockstepAxes', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPAXES,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepAxes)
  })
_sym_db.RegisterMessage(LockstepAxes)

LockstepGetAxesResponse = _reflection.GeneratedProtocolMessageType('LockstepGetAxesResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETAXESRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetAxesResponse)
  })
_sym_db.RegisterMessage(LockstepGetAxesResponse)

LockstepGetTwistRequest = _reflection.GeneratedProtocolMessageType('LockstepGetTwistRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETTWISTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetTwistRequest)
  })
_sym_db.RegisterMessage(LockstepGetTwistRequest)

LockstepGetTwistResponse = _reflection.GeneratedProtocolMessageType('LockstepGetTwistResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETTWISTRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetTwistResponse)
  })
_sym_db.RegisterMessage(LockstepGetTwistResponse)

LockstepGetTwistsResponse = _reflection.GeneratedProtocolMessageType('LockstepGetTwistsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETTWISTSRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetTwistsResponse)
  })
_sym_db.RegisterMessage(LockstepGetTwistsResponse)

LockstepGetOffsetRequest = _reflection.GeneratedProtocolMessageType('LockstepGetOffsetRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETOFFSETREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetOffsetRequest)
  })
_sym_db.RegisterMessage(LockstepGetOffsetRequest)

LockstepGetOffsetResponse = _reflection.GeneratedProtocolMessageType('LockstepGetOffsetResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETOFFSETRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetOffsetResponse)
  })
_sym_db.RegisterMessage(LockstepGetOffsetResponse)

LockstepGetOffsetsResponse = _reflection.GeneratedProtocolMessageType('LockstepGetOffsetsResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPGETOFFSETSRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepGetOffsetsResponse)
  })
_sym_db.RegisterMessage(LockstepGetOffsetsResponse)

LockstepIsEnabledRequest = _reflection.GeneratedProtocolMessageType('LockstepIsEnabledRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPISENABLEDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepIsEnabledRequest)
  })
_sym_db.RegisterMessage(LockstepIsEnabledRequest)

LockstepIsEnabledResponse = _reflection.GeneratedProtocolMessageType('LockstepIsEnabledResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPISENABLEDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepIsEnabledResponse)
  })
_sym_db.RegisterMessage(LockstepIsEnabledResponse)

LockstepToStringRequest = _reflection.GeneratedProtocolMessageType('LockstepToStringRequest', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPTOSTRINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepToStringRequest)
  })
_sym_db.RegisterMessage(LockstepToStringRequest)

LockstepToStringResponse = _reflection.GeneratedProtocolMessageType('LockstepToStringResponse', (_message.Message,), {
  'DESCRIPTOR' : _LOCKSTEPTOSTRINGRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.LockstepToStringResponse)
  })
_sym_db.RegisterMessage(LockstepToStringResponse)

StreamSetupLiveRequest = _reflection.GeneratedProtocolMessageType('StreamSetupLiveRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETUPLIVEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetupLiveRequest)
  })
_sym_db.RegisterMessage(StreamSetupLiveRequest)

StreamSetupLiveCompositeRequest = _reflection.GeneratedProtocolMessageType('StreamSetupLiveCompositeRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETUPLIVECOMPOSITEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetupLiveCompositeRequest)
  })
_sym_db.RegisterMessage(StreamSetupLiveCompositeRequest)

StreamSetupStoreRequest = _reflection.GeneratedProtocolMessageType('StreamSetupStoreRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETUPSTOREREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetupStoreRequest)
  })
_sym_db.RegisterMessage(StreamSetupStoreRequest)

StreamSetupStoreCompositeRequest = _reflection.GeneratedProtocolMessageType('StreamSetupStoreCompositeRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETUPSTORECOMPOSITEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetupStoreCompositeRequest)
  })
_sym_db.RegisterMessage(StreamSetupStoreCompositeRequest)

StreamSetupStoreArbitraryAxesRequest = _reflection.GeneratedProtocolMessageType('StreamSetupStoreArbitraryAxesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETUPSTOREARBITRARYAXESREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetupStoreArbitraryAxesRequest)
  })
_sym_db.RegisterMessage(StreamSetupStoreArbitraryAxesRequest)

StreamCallRequest = _reflection.GeneratedProtocolMessageType('StreamCallRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCALLREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamCallRequest)
  })
_sym_db.RegisterMessage(StreamCallRequest)

StreamLineRequest = _reflection.GeneratedProtocolMessageType('StreamLineRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMLINEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamLineRequest)
  })
_sym_db.RegisterMessage(StreamLineRequest)

StreamArcRequest = _reflection.GeneratedProtocolMessageType('StreamArcRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMARCREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamArcRequest)
  })
_sym_db.RegisterMessage(StreamArcRequest)

StreamCircleRequest = _reflection.GeneratedProtocolMessageType('StreamCircleRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCIRCLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamCircleRequest)
  })
_sym_db.RegisterMessage(StreamCircleRequest)

StreamWaitDigitalInputRequest = _reflection.GeneratedProtocolMessageType('StreamWaitDigitalInputRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMWAITDIGITALINPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamWaitDigitalInputRequest)
  })
_sym_db.RegisterMessage(StreamWaitDigitalInputRequest)

StreamWaitAnalogInputRequest = _reflection.GeneratedProtocolMessageType('StreamWaitAnalogInputRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMWAITANALOGINPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamWaitAnalogInputRequest)
  })
_sym_db.RegisterMessage(StreamWaitAnalogInputRequest)

StreamSetDigitalOutputRequest = _reflection.GeneratedProtocolMessageType('StreamSetDigitalOutputRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETDIGITALOUTPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetDigitalOutputRequest)
  })
_sym_db.RegisterMessage(StreamSetDigitalOutputRequest)

StreamSetAnalogOutputRequest = _reflection.GeneratedProtocolMessageType('StreamSetAnalogOutputRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETANALOGOUTPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetAnalogOutputRequest)
  })
_sym_db.RegisterMessage(StreamSetAnalogOutputRequest)

StreamToggleDigitalOutputRequest = _reflection.GeneratedProtocolMessageType('StreamToggleDigitalOutputRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTOGGLEDIGITALOUTPUTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamToggleDigitalOutputRequest)
  })
_sym_db.RegisterMessage(StreamToggleDigitalOutputRequest)

StreamWaitRequest = _reflection.GeneratedProtocolMessageType('StreamWaitRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMWAITREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamWaitRequest)
  })
_sym_db.RegisterMessage(StreamWaitRequest)

StreamWaitUntilIdleRequest = _reflection.GeneratedProtocolMessageType('StreamWaitUntilIdleRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMWAITUNTILIDLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamWaitUntilIdleRequest)
  })
_sym_db.RegisterMessage(StreamWaitUntilIdleRequest)

StreamCorkRequest = _reflection.GeneratedProtocolMessageType('StreamCorkRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMCORKREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamCorkRequest)
  })
_sym_db.RegisterMessage(StreamCorkRequest)

StreamUncorkRequest = _reflection.GeneratedProtocolMessageType('StreamUncorkRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMUNCORKREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamUncorkRequest)
  })
_sym_db.RegisterMessage(StreamUncorkRequest)

StreamIsBusyRequest = _reflection.GeneratedProtocolMessageType('StreamIsBusyRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMISBUSYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamIsBusyRequest)
  })
_sym_db.RegisterMessage(StreamIsBusyRequest)

StreamIsBusyResponse = _reflection.GeneratedProtocolMessageType('StreamIsBusyResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMISBUSYRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamIsBusyResponse)
  })
_sym_db.RegisterMessage(StreamIsBusyResponse)

StreamGetAxesRequest = _reflection.GeneratedProtocolMessageType('StreamGetAxesRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETAXESREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetAxesRequest)
  })
_sym_db.RegisterMessage(StreamGetAxesRequest)

StreamGetAxesResponse = _reflection.GeneratedProtocolMessageType('StreamGetAxesResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETAXESRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetAxesResponse)
  })
_sym_db.RegisterMessage(StreamGetAxesResponse)

StreamGetModeRequest = _reflection.GeneratedProtocolMessageType('StreamGetModeRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMODEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetModeRequest)
  })
_sym_db.RegisterMessage(StreamGetModeRequest)

StreamGetModeResponse = _reflection.GeneratedProtocolMessageType('StreamGetModeResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMODERESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetModeResponse)
  })
_sym_db.RegisterMessage(StreamGetModeResponse)

StreamGetMaxSpeedRequest = _reflection.GeneratedProtocolMessageType('StreamGetMaxSpeedRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMAXSPEEDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetMaxSpeedRequest)
  })
_sym_db.RegisterMessage(StreamGetMaxSpeedRequest)

StreamGetMaxSpeedResponse = _reflection.GeneratedProtocolMessageType('StreamGetMaxSpeedResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMAXSPEEDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetMaxSpeedResponse)
  })
_sym_db.RegisterMessage(StreamGetMaxSpeedResponse)

StreamSetMaxSpeedRequest = _reflection.GeneratedProtocolMessageType('StreamSetMaxSpeedRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETMAXSPEEDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetMaxSpeedRequest)
  })
_sym_db.RegisterMessage(StreamSetMaxSpeedRequest)

StreamGetMaxTangentialAccelerationRequest = _reflection.GeneratedProtocolMessageType('StreamGetMaxTangentialAccelerationRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMAXTANGENTIALACCELERATIONREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetMaxTangentialAccelerationRequest)
  })
_sym_db.RegisterMessage(StreamGetMaxTangentialAccelerationRequest)

StreamGetMaxTangentialAccelerationResponse = _reflection.GeneratedProtocolMessageType('StreamGetMaxTangentialAccelerationResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMAXTANGENTIALACCELERATIONRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetMaxTangentialAccelerationResponse)
  })
_sym_db.RegisterMessage(StreamGetMaxTangentialAccelerationResponse)

StreamSetMaxTangentialAccelerationRequest = _reflection.GeneratedProtocolMessageType('StreamSetMaxTangentialAccelerationRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETMAXTANGENTIALACCELERATIONREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetMaxTangentialAccelerationRequest)
  })
_sym_db.RegisterMessage(StreamSetMaxTangentialAccelerationRequest)

StreamGetMaxCentripetalAccelerationRequest = _reflection.GeneratedProtocolMessageType('StreamGetMaxCentripetalAccelerationRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMAXCENTRIPETALACCELERATIONREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetMaxCentripetalAccelerationRequest)
  })
_sym_db.RegisterMessage(StreamGetMaxCentripetalAccelerationRequest)

StreamGetMaxCentripetalAccelerationResponse = _reflection.GeneratedProtocolMessageType('StreamGetMaxCentripetalAccelerationResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMGETMAXCENTRIPETALACCELERATIONRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamGetMaxCentripetalAccelerationResponse)
  })
_sym_db.RegisterMessage(StreamGetMaxCentripetalAccelerationResponse)

StreamSetMaxCentripetalAccelerationRequest = _reflection.GeneratedProtocolMessageType('StreamSetMaxCentripetalAccelerationRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMSETMAXCENTRIPETALACCELERATIONREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamSetMaxCentripetalAccelerationRequest)
  })
_sym_db.RegisterMessage(StreamSetMaxCentripetalAccelerationRequest)

StreamToStringRequest = _reflection.GeneratedProtocolMessageType('StreamToStringRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTOSTRINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamToStringRequest)
  })
_sym_db.RegisterMessage(StreamToStringRequest)

StreamToStringResponse = _reflection.GeneratedProtocolMessageType('StreamToStringResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMTOSTRINGRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamToStringResponse)
  })
_sym_db.RegisterMessage(StreamToStringResponse)

StreamDisableRequest = _reflection.GeneratedProtocolMessageType('StreamDisableRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMDISABLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamDisableRequest)
  })
_sym_db.RegisterMessage(StreamDisableRequest)

StreamBufferGetContentRequest = _reflection.GeneratedProtocolMessageType('StreamBufferGetContentRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBUFFERGETCONTENTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamBufferGetContentRequest)
  })
_sym_db.RegisterMessage(StreamBufferGetContentRequest)

StreamBufferGetContentResponse = _reflection.GeneratedProtocolMessageType('StreamBufferGetContentResponse', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBUFFERGETCONTENTRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamBufferGetContentResponse)
  })
_sym_db.RegisterMessage(StreamBufferGetContentResponse)

StreamBufferEraseRequest = _reflection.GeneratedProtocolMessageType('StreamBufferEraseRequest', (_message.Message,), {
  'DESCRIPTOR' : _STREAMBUFFERERASEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.StreamBufferEraseRequest)
  })
_sym_db.RegisterMessage(StreamBufferEraseRequest)

BinaryReplyOnlyEvent = _reflection.GeneratedProtocolMessageType('BinaryReplyOnlyEvent', (_message.Message,), {
  'DESCRIPTOR' : _BINARYREPLYONLYEVENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryReplyOnlyEvent)
  })
_sym_db.RegisterMessage(BinaryReplyOnlyEvent)

OpenBinaryInterfaceRequest = _reflection.GeneratedProtocolMessageType('OpenBinaryInterfaceRequest', (_message.Message,), {
  'DESCRIPTOR' : _OPENBINARYINTERFACEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.OpenBinaryInterfaceRequest)
  })
_sym_db.RegisterMessage(OpenBinaryInterfaceRequest)

UnknownBinaryResponseEvent = _reflection.GeneratedProtocolMessageType('UnknownBinaryResponseEvent', (_message.Message,), {
  'DESCRIPTOR' : _UNKNOWNBINARYRESPONSEEVENT,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.UnknownBinaryResponseEvent)
  })
_sym_db.RegisterMessage(UnknownBinaryResponseEvent)

GenericBinaryRequest = _reflection.GeneratedProtocolMessageType('GenericBinaryRequest', (_message.Message,), {
  'DESCRIPTOR' : _GENERICBINARYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.GenericBinaryRequest)
  })
_sym_db.RegisterMessage(GenericBinaryRequest)

BinaryMessage = _reflection.GeneratedProtocolMessageType('BinaryMessage', (_message.Message,), {
  'DESCRIPTOR' : _BINARYMESSAGE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryMessage)
  })
_sym_db.RegisterMessage(BinaryMessage)

BinaryMessageCollection = _reflection.GeneratedProtocolMessageType('BinaryMessageCollection', (_message.Message,), {
  'DESCRIPTOR' : _BINARYMESSAGECOLLECTION,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryMessageCollection)
  })
_sym_db.RegisterMessage(BinaryMessageCollection)

BinaryDeviceRenumberRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceRenumberRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICERENUMBERREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceRenumberRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceRenumberRequest)

BinaryDeviceRenumberResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceRenumberResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICERENUMBERRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceRenumberResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceRenumberResponse)

BinaryDeviceIdentifyRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceIdentifyRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEIDENTIFYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceIdentifyRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceIdentifyRequest)

BinaryDeviceIdentity = _reflection.GeneratedProtocolMessageType('BinaryDeviceIdentity', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEIDENTITY,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceIdentity)
  })
_sym_db.RegisterMessage(BinaryDeviceIdentity)

BinaryDeviceGetIdentityRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceGetIdentityRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEGETIDENTITYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceGetIdentityRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceGetIdentityRequest)

BinaryDeviceGetIdentityResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceGetIdentityResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEGETIDENTITYRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceGetIdentityResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceGetIdentityResponse)

BinaryDeviceGetIsIdentifiedRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceGetIsIdentifiedRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEGETISIDENTIFIEDREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceGetIsIdentifiedRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceGetIsIdentifiedRequest)

BinaryDeviceGetIsIdentifiedResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceGetIsIdentifiedResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEGETISIDENTIFIEDRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceGetIsIdentifiedResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceGetIsIdentifiedResponse)

BinaryGenericWithUnitsRequest = _reflection.GeneratedProtocolMessageType('BinaryGenericWithUnitsRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYGENERICWITHUNITSREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryGenericWithUnitsRequest)
  })
_sym_db.RegisterMessage(BinaryGenericWithUnitsRequest)

BinaryGenericWithUnitsResponse = _reflection.GeneratedProtocolMessageType('BinaryGenericWithUnitsResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYGENERICWITHUNITSRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryGenericWithUnitsResponse)
  })
_sym_db.RegisterMessage(BinaryGenericWithUnitsResponse)

BinaryDeviceHomeRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceHomeRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEHOMEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceHomeRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceHomeRequest)

BinaryDeviceMovementResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceMovementResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEMOVEMENTRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceMovementResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceMovementResponse)

BinaryDeviceMoveRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceMoveRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEMOVEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceMoveRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceMoveRequest)

BinaryDeviceStopRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceStopRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICESTOPREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceStopRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceStopRequest)

BinaryDeviceWaitUntilIdleRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceWaitUntilIdleRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEWAITUNTILIDLEREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceWaitUntilIdleRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceWaitUntilIdleRequest)

BinaryDeviceIsBusyRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceIsBusyRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEISBUSYREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceIsBusyRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceIsBusyRequest)

BinaryDeviceIsBusyResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceIsBusyResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEISBUSYRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceIsBusyResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceIsBusyResponse)

BinaryDeviceDetectRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceDetectRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEDETECTREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceDetectRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceDetectRequest)

BinaryDeviceDetectResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceDetectResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEDETECTRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceDetectResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceDetectResponse)

BinaryDeviceGetSettingRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceGetSettingRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEGETSETTINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceGetSettingRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceGetSettingRequest)

BinaryDeviceGetSettingResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceGetSettingResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEGETSETTINGRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceGetSettingResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceGetSettingResponse)

BinaryDeviceSetSettingRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceSetSettingRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICESETSETTINGREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceSetSettingRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceSetSettingRequest)

BinaryDeviceParkRequest = _reflection.GeneratedProtocolMessageType('BinaryDeviceParkRequest', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEPARKREQUEST,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceParkRequest)
  })
_sym_db.RegisterMessage(BinaryDeviceParkRequest)

BinaryDeviceParkResponse = _reflection.GeneratedProtocolMessageType('BinaryDeviceParkResponse', (_message.Message,), {
  'DESCRIPTOR' : _BINARYDEVICEPARKRESPONSE,
  '__module__' : 'protobufs.main_pb2'
  # @@protoc_insertion_point(class_scope:zaber.motion.protobufs.BinaryDeviceParkResponse)
  })
_sym_db.RegisterMessage(BinaryDeviceParkResponse)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
